@@ -44,6 +44,10 @@ assignOptions <- function(options) {
 		    #in Analysis "cross", AnalysisVariables can be "Force;Speed;mean". 1st is Y, 2nd is X. "mean" can also be "max"
 		    #Analysis "cross" can have a double XY plot, AnalysisVariables = "Speed,Power;Load;mean"
 		    #	1st: Speed,power are Y (left and right), 2n: Load is X.
+		    #In interssession, x should be along time. In order to recicle paintCrossVariables, a 4th member is sent: "Date".
+		    #	Power;Load;mean;Date will be an Power / Date (with Load as seriesName)
+		    #	Speed;Load;mean;Date will be an Speed / Date (with Load as seriesName)
+		    #	Force;Load;mean;Date will be an Force / Date (with Load as seriesName)
 		    #
 		    #in Analysis "powerBars", AnalysisVariables can be:
 		    #	"TimeToPeakPower;Range", or eg: "NoTimeToPeakPower;NoRange"
@@ -72,7 +76,8 @@ assignOptions <- function(options) {
 		    DecimalSeparator	= options[25],
 		    Title		= options[26],
 		    OperatingSystem	= options[27],	#if this changes, change it also at start of this R file
-		    Debug		= options[30]
+		    Debug		= options[30],
+		    CrossValidate	= options[31]
 		    #Unassigned here:
 		    #	englishWords [28]
 		    #	translatedWords [29]
@@ -258,7 +263,12 @@ getSpeed <- function(displacement, smoothing) {
 	#use position because this does not make erronously change the initial and end of the curve
 	#do spline with displacement is buggy because data is too similar -2, -1, 0, 1, 2, ...
 	position <- cumsum(displacement)
-	positionSpline <- smooth.spline( 1:length(position), position, spar=smoothing)
+	
+	spar <- smoothing
+	if(CROSSVALIDATESMOOTH)
+		spar <- cvParCall(1:length(position), position)
+
+	positionSpline <- smooth.spline( 1:length(position), position, spar=spar)
 	
 	#get speed converting from position to displacement, but repeat first value because it's missing on the diff process
 	#do not hijack spline like this because this works for speed, but then acceleration has big error
@@ -271,14 +281,19 @@ getSpeed <- function(displacement, smoothing) {
 	return (speedSpline)
 }
 
-#same smoothing than getSped
+#same smoothing than getSpeed
 getPositionSmoothed <- function(displacement, smoothing) {
 	#no change affected by encoderConfiguration
 	
 	#use position because this does not make erronously change the initial and end of the curve
 	#do spline with displacement is buggy because data is too similar -2, -1, 0, 1, 2, ...
 	position <- cumsum(displacement)
-	positionSpline <- smooth.spline( 1:length(position), position, spar=smoothing)
+
+	spar <- smoothing
+	if(CROSSVALIDATESMOOTH)
+		spar <- cvParCall(1:length(displacement), displacement)
+
+	positionSpline <- smooth.spline( 1:length(position), position, spar=spar)
 	
 	return (positionSpline$y)
 }
@@ -296,6 +311,20 @@ getAcceleration <- function(speed) {
 	return (predict( speed, deriv=1 ))
 }
 
+smoothSplineSafe <- function(a,b) 
+{
+	out <- tryCatch(
+			{
+				smooth.spline(a,b)
+			},        
+			error=function(cond) {
+				message(cond)
+				return(NULL)
+			}
+			)
+	return (out)
+}
+
 #gearedDown is positive, normally 2
 #this is not used on inertial machines
 getMass <- function(mass, gearedDown, angle) {
@@ -311,7 +340,7 @@ getMass <- function(mass, gearedDown, angle) {
 
 
 #used in alls eccons
-reduceCurveBySpeed <- function(eccon, row, startT, startH, displacement, smoothingOneC) 
+reduceCurveBySpeed <- function(eccon, startT, startH, displacement, smoothingOneC) 
 {
 	#In 1.4.0 and before, we use smoothingOneEC on "ec", "ce"
 	#but the problem is findSmoothingsEC has problems knowing the smoothingEC when users stays stand up lot of time before jump.
@@ -328,6 +357,7 @@ reduceCurveBySpeed <- function(eccon, row, startT, startH, displacement, smoothi
 	speed <- getSpeed(displacement, smoothing)
 	
 	speed.ext=extrema(speed$y)
+	print(speed.ext)
 
 	#in order to reduce curve by speed, we search the cross of speed (in 0m/s)
         #before and after the peak value, but in "ec" and "ce" there are two peak values:
@@ -360,7 +390,7 @@ reduceCurveBySpeed <- function(eccon, row, startT, startH, displacement, smoothi
 	} else if(eccon=="ce") {
 		time1 = min(which(speed$y == max(speed$y)))
 		time2 = max(which(speed$y == min(speed$y)))
-	} else { #c
+	} else { #c, ecS, ceS
 		speed$y=abs(speed$y)
 		time1 = min(which(speed$y == max(speed$y)))
 		time2 = max(which(speed$y == max(speed$y)))
@@ -739,9 +769,9 @@ getDynamics <- function(encoderConfigurationName,
 			speed, accel, massBody, massExtra, exercisePercentBodyWeight, gearedDown, anglePush, angleWeight,
 			displacement, diameter, inertiaMomentum, smoothing)
 {
-	debugParameters(listN(encoderConfigurationName,
-			     speed, accel, massBody, massExtra, exercisePercentBodyWeight, gearedDown, anglePush, angleWeight,
-			     displacement, diameter, inertiaMomentum, smoothing), "getDynamics")
+	#debugParameters(listN(encoderConfigurationName,
+	#		     speed, accel, massBody, massExtra, exercisePercentBodyWeight, gearedDown, anglePush, angleWeight,
+	#		     displacement, diameter, inertiaMomentum, smoothing), "getDynamics")
 	
 
 	massBody = getMassBodyByExercise(massBody,exercisePercentBodyWeight)
@@ -974,7 +1004,7 @@ getDisplacementInertial <- function(displacement, encoderConfigurationName, diam
 #positionStart is the height at the start of the curve. It's used only on realtime capture.
 #displacementPerson has to be adjusted for every repetition using the positionStart relative to the start of the movement
 #Eg, at start of the capture position is always 0, then goes down (first eccentric phase), and then starts con-ecc, con-ecc, con-ecc, ...
-#To divide the con-ecc in two phases (because for the encoder is only one phsae because it rotates in the same direction), we need to know the positionAtStart
+#To divide the con-ecc in two phases (because for the encoder is only one phase because it rotates in the same direction), we need to know the positionAtStart
 getDisplacementInertialBody <- function(positionStart, displacement, draw, title) 
 {
 	position=cumsum(displacement)
@@ -995,7 +1025,7 @@ getDisplacementInertialBody <- function(positionStart, displacement, draw, title
 		   ( position[position.ext$maxindex[1]] >= ( max(abs(position)) *.2 ) ) ) {
 			displacement = displacement * -1
 			position=cumsum(displacement)
-			position.ext=extrema(position)
+			#position.ext=extrema(position)
 		}
 
 		#unused
@@ -1115,7 +1145,53 @@ getInertialDiametersPerMs <- function(displacement, diametersPerTick)
   return(diameter)
 }
 
+#----------- Begin spar with crossvalidation (Aleix Ruiz de Villa) -------------
 
+cvParCall <- function(x, y) {
+	parRange <- seq(0.1, 1, 0.05)
+	cvResults <- cvPar(x, y, parRange)
+
+	## Agafem la spar que te un error més petit
+	#print( paste('The best spar is: ', parRange[ which.min(cvResults) ] ) )
+	write("CrossValidation:", stderr())
+	write(parRange[which.min(cvResults)], stderr())
+	return (parRange[which.min(cvResults)])
+}
+cvPar <- function(x, y, parRange, cvProp = 0.8) {
+
+	n <- length(x)
+	nTrain <- floor( cvProp * n )
+	nTest <- n - nTrain
+
+	cvParError <- vector(length=length(parRange))
+	for( parPos in 1:length(parRange) ){
+		selectedPar <- parRange[ parPos ]
+
+		## Separem la mostra en train i test
+		indexTrain <- sample(1:n, nTrain)
+		indexTest <- (1:n)[-indexTrain]
+		xTrain <- x[ indexTrain ]
+		xTest <- x[ indexTest ]
+		yTrain <- y[ indexTrain ]
+		yTest <- y[ indexTest ]
+
+		## Fem servir les dades del train per a construir els splines
+		splineModel <- smooth.spline(xTrain, yTrain, spar = selectedPar)
+
+		## Fem la prediccio sobre la mostra test
+		predictedBySpline <- predict(splineModel, xTest)
+		# plot(xTest, predictedBySpline$y, col = 'blue')
+		# lines(xTest, yTest, col = 'green', type = 'p')
+
+		## Calculem els errors
+		predictionError <- sqrt( mean( (predictedBySpline$y - yTest)^2 ) )
+		cvParError[ parPos ] <- predictionError
+	}
+
+	return(cvParError)
+}
+
+#----------- end spar with crossvalidation -------------
 
 #----------- Begin debug file output -------------
 debugParameters <- function (parameterList, currentFunction) 
