@@ -115,6 +115,9 @@ public class Chronopic {
 		//-- produzca un timeout
 		ok = Read_cambio(trama);
 
+		LogB.Warning("after Read_cambio =");
+		LogB.Warning(ok.ToString());
+
 		//-- Si hay timeout o errores
 		if (ok==false) {
 			plataforma = Plataforma.UNKNOW;
@@ -167,7 +170,7 @@ public class Chronopic {
 		}
 
 		
-		sp.Write("V");
+		sp.Write("n");
 		LogB.Information("Version: " + 
 				(char) sp.ReadByte() +
 				(char) sp.ReadByte() +
@@ -310,6 +313,8 @@ public class Chronopic {
 			do {
 				try {
 					n = sp.Read(respuesta,count,5-count);
+					LogB.Warning("respuesta = ");
+					LogB.Warning(respuesta.ToString());
 					count+=n;
 					success = true;
 				} catch {}
@@ -368,9 +373,36 @@ public class Chronopic {
 		}
 	}
 
+	/*
+	 * this will read what's in the serial port until time out
+	*/	
+	private void flushByTimeOut()
+	{
+		byte[] buffer = new byte[256];
+
+		//try, catch done because mono-1.2.3 throws an exception when there's a timeout
+		//http://bugzilla.gnome.org/show_bug.cgi?id=420520
+		bool timeOut = false;
+		do{
+			try{
+				sp.Read(buffer,0,256);
+				LogB.Debug(" spReaded ");
+			} catch {
+				LogB.Warning(" catchedTimeOut ");
+				timeOut = true;
+			}
+
+		} while(! timeOut);
+	}
+
+
 	public void Flush() {
 		flush();
 	}
+	
+	public void FlushByTimeOut() {
+		flushByTimeOut();
+	}
 
 	/**********************************/
 	/* TIPOS PRIVADOS                 */
