@@ -408,8 +408,10 @@ public class Constants
 	public static string FileNameContactPlatformModular = "modular_platform_with_chronopic.jpg";
 	public static string FileNameInfrared = "infrared.jpg";
 	
-	public static string FileNameEncoderAnalyzeCurrentSignalIcon = "encoder-analyze-current-signal.png";
-	public static string FileNameEncoderAnalyzeSavedCurvesIcon = "encoder-analyze-saved-curves.png";
+	public static string FileNameEncoderAnalyzeIndividualCurrentSetIcon = "encoder-analyze-individual-current-set.png";
+	public static string FileNameEncoderAnalyzeIndividualCurrentSessionIcon = "encoder-analyze-individual-current-session.png";
+	public static string FileNameEncoderAnalyzeIndividualAllSessionsIcon = "encoder-analyze-individual-all-sessions.png";
+	public static string FileNameEncoderAnalyzeGroupalCurrentSessionIcon = "encoder-analyze-groupal-current-session.png";
 
 	public static string FileNameEncoderAnalyzePowerbarsIcon = "encoder-analyze-powerbars.png";
 	public static string FileNameEncoderAnalyzeCrossIcon = "encoder-analyze-cross.png";
@@ -437,7 +439,8 @@ public class Constants
 	
 	public static string FileNameSelectorJumps = "chronojump-jumps-small.png";
 	public static string FileNameSelectorRuns = "chronojump-runs-small.png";
-	public static string FileNameSelectorEncoder = "chronojump-encoder-small.jpg";
+	public static string FileNameSelectorEncoderGravitatory = "chronojump-encoder-small.png";
+	public static string FileNameSelectorEncoderInertial = "chronojump-inertial.png";
 
 	public static string FileNameLog = "log_chronojump.txt";
 	public static string FileNameLogOld = "log_chronojump_old.txt";
@@ -612,7 +615,7 @@ public class Constants
 	//heightmetric contains 2 spins
 	public enum GenericWindowShow {
 		ENTRY, ENTRY2, ENTRY3, SPININT, SPININT2, SPININT3, SPINDOUBLE, HBOXSPINDOUBLE2, 
-		HEIGHTMETRIC, COMBO, COMBOALLNONESELECTED, TEXTVIEW, TREEVIEW
+		HEIGHTMETRIC, COMBO, COMBOALLNONESELECTED, BUTTONMIDDLE, TEXTVIEW, TREEVIEW
 	}
 
 
@@ -680,6 +683,8 @@ public class Constants
 		JUMPS, RUNS, ENCODER
 	}
 
+	public enum Menuitem_modes { JUMPS, RUNS, POWERGRAVITATORY, POWERINERTIAL, OTHER }
+
 	public static string All = "All";
 	public static string None = "None";
 	public static string Invert = "Invert";
@@ -734,6 +739,7 @@ public class Constants
 	public static string EccentricConcentric = "Eccentric-concentric";
 	//public static string ConcentricEccentric = "Concentric-eccentric";
 
+	public enum EncoderGI {ALL, GRAVITATORY, INERTIAL}
 	public enum EncoderCheckFileOp { CAPTURE_EXPORT_ALL, ANALYZE_SAVE_IMAGE, ANALYZE_SAVE_AB, ANALYZE_SAVE_TABLE}
 
 	public static double EncoderErrorCode = -1;
