@@ -165,6 +165,7 @@ public class EncoderGraphROptions
 	public string englishWords;
 	public string translatedWords;
 	public bool debug;
+	public bool crossValidate;
 	
 	public EncoderGraphROptions(
 			string inputData, string outputGraph, string outputData1, 
@@ -172,7 +173,7 @@ public class EncoderGraphROptions
 			EncoderParams ep,
 			string title, string operatingSystem,
 			string englishWords, string translatedWords,
-			bool debug)
+			bool debug, bool crossValidate)
 	{
 		this.inputData = inputData;
 		this.outputGraph = outputGraph;
@@ -185,6 +186,7 @@ public class EncoderGraphROptions
 		this.englishWords = englishWords;
 		this.translatedWords = translatedWords;
 		this.debug = debug;
+		this.crossValidate = crossValidate;
 	}
 
 	public override string ToString() {
@@ -199,7 +201,8 @@ public class EncoderGraphROptions
 			"#operatingsystem\n" + 	operatingSystem + "\n" +
 			"#englishWords\n" + 	englishWords + "\n" +
 			"#translatedWords\n" + 	translatedWords + "\n" +
-			"#debug\n" +		Util.BoolToRBool(debug) + "\n";
+			"#debug\n" +		Util.BoolToRBool(debug) + "\n" +
+			"#crossValidate\n" +	Util.BoolToRBool(crossValidate) + "\n";
 	}
 	
 
@@ -297,6 +300,7 @@ public class EncoderCurve
 
 	//http://stackoverflow.com/questions/894263/how-to-identify-if-a-string-is-a-number
 	//this does not check if decimal point is a different character (eg '.' or ',')
+	//note new method IsNumber on util.cs is better than this
 	public bool IsNumberN() {
 		int num;
 		return int.TryParse(N, out num);
@@ -387,6 +391,14 @@ public class EncoderCurve
 			return Util.ChangeChars(str, ":::", ",");
 	}
 	
+	public double MeanSpeedD { get { return Convert.ToDouble(MeanSpeed); } }
+	public double MaxSpeedD  { get { return Convert.ToDouble(MaxSpeed);  } }
+	public double MeanPowerD { get { return Convert.ToDouble(MeanPower); } }
+	public double PeakPowerD { get { return Convert.ToDouble(PeakPower); } }
+	public double MeanForceD { get { return Convert.ToDouble(MeanForce); } }
+	public double MaxForceD  { get { return Convert.ToDouble(MaxForce);  } }
+
+	
 	~EncoderCurve() {}
 }
 
@@ -402,7 +414,6 @@ public class EncoderSignal
 
 	//this can be an eccentric or concentric curve
 	public int FindPosOfBest(string variable) {
-		//TODO: change for the rest of stuff
 		double bestValue = 0;
 		int bestValuePos = 0;
 		int i = 0;
@@ -419,6 +430,35 @@ public class EncoderSignal
 		return bestValuePos;
 	}
 	
+	//this is an ecc-con curve
+	public int FindPosOfBestEccCon(string variable) 
+	{
+		double eccValue = 0;
+		double conValue = 0;
+
+		double bestValue = 0; //will be ecc-con average
+		int bestValuePos = 0; //will be the position of the ecc
+		int i = 0;
+		
+		bool ecc = true;
+		foreach(EncoderCurve curve in curves) 
+		{
+			if(ecc) {
+				eccValue = curve.GetParameter(variable);
+			} else {
+				conValue = curve.GetParameter(variable);
+				if( ( (eccValue + conValue) / 2 ) > bestValue) {
+					bestValue = (eccValue + conValue) / 2;
+					bestValuePos = i -1;
+				}
+			}
+
+			ecc = ! ecc;
+			i ++;
+		}
+		return bestValuePos;
+	}
+	
 	~EncoderSignal() {}
 }
 
@@ -780,7 +820,21 @@ public class EncoderSQL
 
 }
 
+//related to all reps, not only active
+public class EncoderPersonCurvesInDBDeep
+{
+	public double extraWeight;
+	public int count; //this count is all reps (not only active)
 
+	public EncoderPersonCurvesInDBDeep(double w, int c) {
+		this.extraWeight = w;
+		this.count = c;
+	}
+
+	public override string ToString() {
+		return count.ToString() + "*" + extraWeight.ToString();// + "Kg";
+	}
+}
 public class EncoderPersonCurvesInDB
 {
 	public int personID;
@@ -789,23 +843,44 @@ public class EncoderPersonCurvesInDB
 	public string sessionDate;
 	public int countActive;
 	public int countAll;
+	public List<EncoderPersonCurvesInDBDeep> lDeep;
 	
 	public EncoderPersonCurvesInDB() {
 	}
-	public EncoderPersonCurvesInDB(int personID, int sessionID, string sessionName, string sessionDate,
-			int countActive, int countAll) {
+	public EncoderPersonCurvesInDB(int personID, int sessionID, string sessionName, string sessionDate) 
+	{
 		this.personID =		personID;
 		this.sessionID = 	sessionID;
 		this.sessionName = 	sessionName;
 		this.sessionDate = 	sessionDate;
-		this.countActive = 	countActive;
-		this.countAll =		countAll;
 	}
 
-	public string [] ToStringArray() {
-		string [] s = { sessionID.ToString(), "", sessionName, sessionDate,
-			countActive.ToString(), countAll.ToString()
-		};
+	public string [] ToStringArray(bool deep) {
+		string [] s;
+
+		//the "" will be for the checkbox on genericWin
+		if(deep) {
+			s = new string[]{ sessionID.ToString(), "", sessionName, sessionDate,
+				//countActive.ToString(), countAll.ToString()
+				countAll.ToString(), DeepPrint()
+			};
+		} else {
+			s = new string[]{ sessionID.ToString(), "", sessionName, sessionDate,
+				//countActive.ToString(), countAll.ToString()
+				countAll.ToString()
+			};
+		}
+
+		return s;
+	}
+
+	private string DeepPrint() {
+		string s = "";
+		string sep = "";
+		foreach(EncoderPersonCurvesInDBDeep e in lDeep) {
+			s += sep + e.ToString();
+			sep = " ";
+		}
 		return s;
 	}
 }
@@ -858,6 +933,7 @@ public class Encoder1RM
 	public int uniqueID;
 	public int personID;
 	public int sessionID;
+	public DateTime date;
 	public int exerciseID;
 	public double load1RM;
 	
@@ -867,20 +943,22 @@ public class Encoder1RM
 	public Encoder1RM() {
 	}
 
-	public Encoder1RM(int uniqueID, int personID, int sessionID, int exerciseID, double load1RM)
+	public Encoder1RM(int uniqueID, int personID, int sessionID, DateTime date, int exerciseID, double load1RM)
 	{
 		this.uniqueID = uniqueID;
 		this.personID = personID;
 		this.sessionID = sessionID;
+		this.date = date;
 		this.exerciseID = exerciseID;
 		this.load1RM = load1RM;
 	}
 
-	public Encoder1RM(int uniqueID, int personID, int sessionID, int exerciseID, double load1RM, string personName, string exerciseName)
+	public Encoder1RM(int uniqueID, int personID, int sessionID, DateTime date, int exerciseID, double load1RM, string personName, string exerciseName)
 	{
 		this.uniqueID = uniqueID;
 		this.personID = personID;
 		this.sessionID = sessionID;
+		this.date = date;
 		this.exerciseID = exerciseID;
 		this.load1RM = load1RM;
 		this.personName = personName;
@@ -893,7 +971,7 @@ public class Encoder1RM
 	}
 	
 	public string [] ToStringArray2() {
-		string [] s = { uniqueID.ToString(), personName, exerciseName, load1RM.ToString() };
+		string [] s = { uniqueID.ToString(), personName, exerciseName, load1RM.ToString(), date.ToShortDateString() };
 		return s;
 	}
 
@@ -906,13 +984,12 @@ public class EncoderCaptureCurve {
 	public int startFrame;
         public int endFrame;
 
-	public EncoderCaptureCurve(bool up, int startFrame, int endFrame)
+	public EncoderCaptureCurve(int startFrame, int endFrame)
 	{
-		this.up = up;
 		this.startFrame = startFrame;
 		this.endFrame = endFrame;
 	}
-
+	
 	public string DirectionAsString() {
 		if(up)
 			return "UP";
@@ -1319,6 +1396,14 @@ public class EncoderConfiguration {
 		}
 	}
 
+	public void SetInertialDefaultOptions() {
+		//after creating Constants.EncoderConfigurationNames.ROTARYAXISINERTIAL
+		inertiaMachine = 900;
+		d = 5;
+		list_d = new List<double>(); 
+		list_d.Add(d);
+	}
+
 	public void ReadParamsFromSQL (string [] strFull) 
 	{
 		//adds other params
