@@ -31,6 +31,8 @@ public abstract class EncoderRProc
 	public enum Status { WAITING, RUNNING, DONE } 
 	public Status status;
 	public bool Debug = false;
+	public bool CrossValidate;
+	public int CurvesReaded;
 
 	protected string optionsFile;	
 	protected EncoderStruct es;
@@ -212,8 +214,24 @@ public abstract class EncoderRProc
 	*/
 	protected void readingError (object sendingProcess, DataReceivedEventArgs errorFromR)
 	{
-		if (! String.IsNullOrEmpty(errorFromR.Data))
-			LogB.Warning(errorFromR.Data);
+		if (String.IsNullOrEmpty(errorFromR.Data))
+			return;
+
+		string str = errorFromR.Data;
+		if(str.Length > 6 && str.StartsWith("***") && str.EndsWith("***")) {
+			/*
+			 * 0123456
+			 * ***1***
+			 * str.Substring(3,1) 1 is the length
+			 */
+			str = str.Substring(3, str.Length -6); 
+			if(Util.IsNumber(str,false))
+				CurvesReaded = Convert.ToInt32(str);
+
+			return;
+		}
+		
+		LogB.Warning(str);
 	}
 
 	public void SendEndProcess() 
@@ -289,15 +307,9 @@ public class EncoderRProcCapture : EncoderRProc
 	//here curve is sent compressed (string. eg: "0*5 1 0 -1*3 2")
 	public void SendCurve(string curveCompressed)
 	{
-		LogB.Debug("writing line 1 -->");
-		
-		//TODO convert comma to point in this doubles
-
-		LogB.Debug("curveSend [displacement array]",curveCompressed);
+		LogB.Information("curveSend [displacement array]",curveCompressed);
 		p.StandardInput.WriteLine(curveCompressed); 	//this will send some lines because compressed data comes with '\n's
 		p.StandardInput.WriteLine("E");		//this will mean the 'E'nd of the curve. Then data can be uncompressed on R
-		
-		LogB.Debug("<-- writen line 1");
 	}	
 	
 	protected override void writeOptionsFile()
@@ -309,7 +321,8 @@ public class EncoderRProcCapture : EncoderRProc
 				es, 
 				false,	//neuromuscularProfile
 				false,	//translate (graphs)
-				Debug
+				Debug,
+				false	//crossValidate (unactive on capture at the moment)
 				).ToString();
 
 		TextWriter writer = File.CreateText(optionsFile);
@@ -349,6 +362,8 @@ public class EncoderRProcAnalyze : EncoderRProc
 
 	protected override bool startProcess() 
 	{
+		CurvesReaded = 0;
+		
 		//If output file is not given, R will try to write in the running folder
 		//in which we may haven't got permissions
 	
@@ -413,9 +428,9 @@ public class EncoderRProcAnalyze : EncoderRProc
 		if(outputFileCheck2 != "")
 			deleteFile(outputFileCheck2);
 		
-		//delete status-5 mark used on export csv
+		//delete status-6 mark used on export csv
 		if(es.Ep.Analysis == "exportCSV")
-			Util.FileDelete(UtilEncoder.GetEncoderStatusTempBaseFileName() + "5.txt");
+			Util.FileDelete(UtilEncoder.GetEncoderStatusTempBaseFileName() + "6.txt");
 
 		//delete 1RM data if exists
 		string specialData = UtilEncoder.GetEncoderSpecialDataTempFileName();
@@ -463,6 +478,8 @@ public class EncoderRProcAnalyze : EncoderRProc
 	
 	protected override bool continueProcess() 
 	{
+		CurvesReaded = 0;
+		
 		//TODO: outputFileCheck creation/deletion here and at startProcess, should be unique
 		string outputFileCheck = "";
 		string outputFileCheck2 = "";
@@ -485,9 +502,9 @@ public class EncoderRProcAnalyze : EncoderRProc
 		if(outputFileCheck2 != "")
 			deleteFile(outputFileCheck2);
 		
-		//delete status-5 mark used on export csv
+		//delete status-6 mark used on export csv
 		if(es.Ep.Analysis == "exportCSV")
-			Util.FileDelete(UtilEncoder.GetEncoderStatusTempBaseFileName() + "5.txt");
+			Util.FileDelete(UtilEncoder.GetEncoderStatusTempBaseFileName() + "6.txt");
 		
 		//delete 1RM data if exists
 		string specialData = UtilEncoder.GetEncoderSpecialDataTempFileName();
@@ -523,7 +540,7 @@ public class EncoderRProcAnalyze : EncoderRProc
 	//copy export from temp file to the file that user has selected
 	private void copyExportedFile() {
 		//wait first this status mark that is created when file is fully exported
-		while ( ! Util.FileExists(UtilEncoder.GetEncoderStatusTempBaseFileName() + "5.txt") ) 
+		while ( ! Util.FileExists(UtilEncoder.GetEncoderStatusTempBaseFileName() + "6.txt") ) 
 			;
 		//copy the file
 		File.Copy(es.OutputData1, ExportFileName, true);
@@ -544,7 +561,8 @@ public class EncoderRProcAnalyze : EncoderRProc
 				es, 
 				neuromuscularProfileDo,
 				translate,
-				Debug
+				Debug,
+				CrossValidate
 				).ToString();
 
 		TextWriter writer = File.CreateText(optionsFile);
