@@ -149,9 +149,15 @@ public class EventExecute
 	protected bool totallyCancelledMulti2;
 	protected bool totallyCancelledMulti3;
 	protected bool totallyCancelledMulti4;
-	
 
 
+	//for reaction time	
+	//on animation lights and discriminative should be false
+	public bool StartIn = true;
+	public Gtk.Button FakeButtonReactionTimeStart;
+	
+	
+
 	//protected EventExecuteWindow eventExecuteWin;
 	//protected ChronoJumpWindow app1;
 	
@@ -483,6 +489,9 @@ public class EventExecute
 		Util.PlaySound(Constants.SoundTypes.BAD, volumeOn);
 	} 
 	
+	public virtual void Manage2() {
+	}
+	
 	//from confirm_window cancel button (thread has not started)
 	//this is NOT called when a event has started and user click on "Cancel"
 	protected void cancel_event_before_start(object o, EventArgs args)
