@@ -35,14 +35,14 @@ public class ReactionTimeExecute : EventExecute
 	private Chronopic cp;
 
 	private ReactionTime reactionTimeDone;
-	
+				
 	public ReactionTimeExecute() {
 	}
 
 	//reactionTime execution
 	public ReactionTimeExecute(int personID, string personName, int sessionID,   
 			Chronopic cp, Gtk.Label event_execute_label_message, Gtk.Window app, int pDN, bool volumeOn,
-			double progressbarLimit, ExecutingGraphData egd
+			double progressbarLimit, ExecutingGraphData egd, string description
 			)
 	{
 		this.personID = personID;
@@ -57,11 +57,14 @@ public class ReactionTimeExecute : EventExecute
 		this.volumeOn = volumeOn;
 		this.progressbarLimit = progressbarLimit;
 		this.egd = egd;
+		this.description = description;
 	
 		fakeButtonUpdateGraph = new Gtk.Button();
 		fakeButtonEventEnded = new Gtk.Button();
 		fakeButtonFinished = new Gtk.Button();
 		fakeButtonThreadDyed = new Gtk.Button();
+				
+		FakeButtonReactionTimeStart = new Gtk.Button();
 		
 		simulated = false;
 			
@@ -96,18 +99,33 @@ public class ReactionTimeExecute : EventExecute
 		//boolean to know if chronopic has been disconnected	
 		chronopicDisconnected = false;
 
-		if (simulated) 
-			platformState = Chronopic.Plataforma.ON;
-		else
+		LogB.Error("at Manage!");
+
+		if (simulated) {
+			if(StartIn)
+				platformState = Chronopic.Plataforma.ON;
+			else
+				platformState = Chronopic.Plataforma.OFF;
+		} else {
 			platformState = chronopicInitialValue(cp);
+		}
+			
+		bool canStart = false;
+		if ( 
+				(StartIn && platformState == Chronopic.Plataforma.ON) ||
+				(! StartIn && platformState == Chronopic.Plataforma.OFF) )
+			canStart = true;
+			
 		
-		
-		if (platformState==Chronopic.Plataforma.ON) {
-			feedbackMessage = Catalog.GetString("You are IN, RELEASE when prepared!");
+		if (canStart) {
+			feedbackMessage = Catalog.GetString("You are IN, RELEASE when prepared!"); //TODO: change this
 			needShowFeedbackMessage = true; 
 			Util.PlaySound(Constants.SoundTypes.CAN_START, volumeOn);
 
-			loggedState = States.ON;
+			if(StartIn)
+				loggedState = States.ON;
+			else
+				loggedState = States.OFF;
 
 			//prepare reactionTime for being cancelled if desired
 			cancel = false;
@@ -115,21 +133,21 @@ public class ReactionTimeExecute : EventExecute
 
 			//in simulated mode, make the jump start just when we arrive to waitEvent at the first time
 			//mark now that we have leaved platform:
-			if (simulated)
-				platformState = Chronopic.Plataforma.OFF;
-			
-			//start thread
-			//Log.Write("Start thread");
-			thread = new Thread(new ThreadStart(waitEvent));
-			GLib.Idle.Add (new GLib.IdleHandler (PulseGTK));
-			
-			LogB.ThreadStart(); 
-			thread.Start(); 
+			if (simulated) {
+				if(StartIn)
+					platformState = Chronopic.Plataforma.OFF;
+				else
+					platformState = Chronopic.Plataforma.ON;
+			}
+	
+			//if discriminative, will fire the buttons	
+			FakeButtonReactionTimeStart.Click();
 		} 
-		else if (platformState==Chronopic.Plataforma.OFF) {
+		else if (! canStart && (platformState == Chronopic.Plataforma.ON || platformState == Chronopic.Plataforma.OFF) )
+		{
 			ConfirmWindow confirmWin;		
 			confirmWin = ConfirmWindow.Show( 
-					Catalog.GetString("You are OUT, come inside and press the 'accept' button"), "", "");
+					Catalog.GetString("You are OUT, come inside and press the 'accept' button"), "", ""); //TODO:change this
 			//System.Media.SystemSounds.Beep.Play();
 			Util.PlaySound(Constants.SoundTypes.BAD, volumeOn);
 
@@ -139,29 +157,48 @@ public class ReactionTimeExecute : EventExecute
 			//if confirmWin.Button_cancel is pressed retuen
 			confirmWin.Button_cancel.Clicked += new EventHandler(cancel_event_before_start);
 		}
-		else { //UNKNOW (Chronopic disconnected, port changed, ...)
+		else { //UNKNOW (Chronopic disconnected, port changed, ...) platformStart == some error
 			chronopicHasBeenDisconnected();
 		}
 	}
 
-	
+	public override void Manage2() 
+	{
+		//start thread
+		//Log.Write("Start thread");
+		thread = new Thread(new ThreadStart(waitEvent));
+		GLib.Idle.Add (new GLib.IdleHandler (PulseGTK));
+
+		LogB.ThreadStart(); 
+		thread.Start(); 
+	}
+
 	protected override void waitEvent ()
 	{
 		double timestamp = 0;
 		bool success = false;
 		
 		bool ok;
-		
+	
+		LogB.Information("Inside waitEvent");	
 		do {
 			if(simulated)
 				ok = true;
 			else 
 				ok = cp.Read_event(out timestamp, out platformState);
+		
+			LogB.Information("Inside do");	
+			LogB.Information("cancel == ");	
+			LogB.Information(cancel.ToString());	
+			LogB.Information("ok == ");	
+			LogB.Information(ok.ToString());	
 			
 			//if (ok) {
 			if (ok && !cancel) {
+				LogB.Information("ok!");	
 				if (platformState == Chronopic.Plataforma.ON && loggedState == States.OFF) 
 				{
+					//LogB.Information("condition guai! hem entrat!");	
 					//has landed
 					if(simulated)
 						timestamp = simulatedTimeLast * 1000; //conversion to milliseconds
@@ -189,6 +226,7 @@ public class ReactionTimeExecute : EventExecute
 				}
 				else if (platformState == Chronopic.Plataforma.OFF && loggedState == States.ON) 
 				{
+					//LogB.Information("condition hem sortit");	
 			
 					//it's out, was inside (= has released)
 					
@@ -256,10 +294,10 @@ public class ReactionTimeExecute : EventExecute
 		uniqueID = SqliteReactionTime.Insert(
 				false, table, 
 				"NULL", personID, sessionID, "", //type
-				time, "", Util.BoolToNegativeInt(simulated)); //time, description, simulated
+				time, description, Util.BoolToNegativeInt(simulated));
 
 		//define the created object
-		eventDone = new ReactionTime(uniqueID, personID, sessionID, time, "", Util.BoolToNegativeInt(simulated)); 
+		eventDone = new ReactionTime(uniqueID, personID, sessionID, time, description, Util.BoolToNegativeInt(simulated)); 
 		
 		//event will be raised, and managed in chronojump.cs
 		fakeButtonFinished.Click();
