@@ -75,6 +75,18 @@ public class ExportSession
 					Catalog.GetString("Cancel"),ResponseType.Cancel,
 					Catalog.GetString("Export"),ResponseType.Accept
 					);
+	
+		//set default name	
+		string nameString = mySession.Name + "_" + mySession.DateShortAsSQL;
+		if(formatFile == "report") {
+			if(UtilAll.IsWindows())
+				nameString += ".htm";
+			else
+				nameString += ".html";
+		} else
+			nameString += ".csv";
+
+		fc.CurrentName = nameString;
 
 		if (fc.Run() == (int)ResponseType.Accept) 
 		{
@@ -154,11 +166,17 @@ public class ExportSession
 		//Leave SQL opened in all this process
 		Sqlite.Open(); // ------------------------------
 		
-		myJumps= SqliteJump.SelectJumps(true, mySession.UniqueID, -1, "", "");
+		myJumps= SqliteJump.SelectJumps(true, mySession.UniqueID, -1, "", "",
+				Sqlite.Orders_by.DEFAULT, -1);
+
 		myJumpsRj = SqliteJumpRj.SelectJumps(true, mySession.UniqueID, -1, "", "");
-		myRuns= SqliteRun.SelectRuns(true, mySession.UniqueID, -1, "");
+		myRuns= SqliteRun.SelectRuns(true, mySession.UniqueID, -1, "",
+				Sqlite.Orders_by.DEFAULT, -1);
+
 		myRunsInterval = SqliteRunInterval.SelectRuns(true, mySession.UniqueID, -1, "");
-		myReactionTimes = SqliteReactionTime.SelectReactionTimes(true, mySession.UniqueID, -1);
+		myReactionTimes = SqliteReactionTime.SelectReactionTimes(true, mySession.UniqueID, -1,
+				Sqlite.Orders_by.DEFAULT, -1);
+
 		myPulses = SqlitePulse.SelectPulses(true, mySession.UniqueID, -1);
 		myMCs = SqliteMultiChronopic.SelectTests(true, mySession.UniqueID, -1);
 		
