@@ -138,8 +138,12 @@ public partial class ChronoJumpWindow
 
 		encoderCaptureListStore = new Gtk.ListStore (typeof (EncoderCurve));
 		
-		foreach (EncoderCurve curve in encoderCaptureCurves) 
+		repetitiveConditionsWin.ResetBestSetValue();
+		foreach (EncoderCurve curve in encoderCaptureCurves) {
 			encoderCaptureListStore.AppendValues (curve);
+				
+			repetitiveConditionsWin.UpdateBestSetValue(curve);
+		}
 
 		treeview_encoder_capture_curves.Model = encoderCaptureListStore;
 
@@ -334,17 +338,14 @@ public partial class ChronoJumpWindow
 	{
 		int bestRow = 0;
 		if(saveOption == Constants.EncoderAutoSaveCurve.BEST) {
-			//get the concentric curves
-			EncoderSignal encoderSignal = new EncoderSignal(treeviewEncoderCaptureCurvesGetCurves(AllEccCon.CON));
-			bestRow = encoderSignal.FindPosOfBest(mainVariable);
-			
-			//convert from c to ec. eg.
-			//three concentric curves: c[0], c[1], c[2]
-			//coming from three ecc-con: e[0], c[1], e[2], c[3], e[4], c[5]
-			//if from first list, c[2] is the best, then on second list it will be the ec curve: e[4],c[5]
-			//always multiply *2
-			if(ecconLast != "c")
-				bestRow *= 2;
+			if(ecconLast == "c") {
+				//get the concentric curves
+				EncoderSignal encoderSignal = new EncoderSignal(treeviewEncoderCaptureCurvesGetCurves(AllEccCon.CON));
+				bestRow = encoderSignal.FindPosOfBest(mainVariable);
+			} else {
+				EncoderSignal encoderSignal = new EncoderSignal(treeviewEncoderCaptureCurvesGetCurves(AllEccCon.ALL));
+				bestRow = encoderSignal.FindPosOfBestEccCon(mainVariable); //will be pos of the ecc
+			}
 		}
 
 
@@ -413,22 +414,9 @@ public partial class ChronoJumpWindow
 			iterOk = encoderCaptureListStore.IterNext (ref iter);
 		}
 		
-		//combo_encoder_capture_show_save_curve_button();
-		
-		/* temporarily removed message
-		 *
-		string message = "";
-		if(saveOption == Constants.EncoderAutoSaveCurve.NONE)
-			message = Catalog.GetString("Removed");
-		else
-			message = Catalog.GetString("Saved");
-		label_encoder_curve_action.Text = message + " " + messageRows;
-		*/
-
-			
-		updateUserCurvesLabelsAndCombo(true);
-		
 		Sqlite.Close();
+
+		prepareAnalyzeRepetitions();
 			
 		callPlotCurvesGraphDoPlot();
 	}
@@ -482,29 +470,10 @@ public partial class ChronoJumpWindow
 
 			iterOk = encoderCaptureListStore.IterNext (ref iter);
 		}
-		//combo_encoder_capture_show_save_curve_button();
 			
 		callPlotCurvesGraphDoPlot();
 	}
 
-	/*	
-	void combo_encoder_capture_show_save_curve_button () {
-		label_encoder_curve_action.Text = "";
-
-		TreeIter iter;
-		bool iterOk = encoderCaptureListStore.GetIterFirst(out iter);
-		while(iterOk) {
-			if(((EncoderCurve) encoderCaptureListStore.GetValue (iter, 0)).Record) {
-				encoderButtonsSensitive(encoderSensEnum.SELECTEDCURVE);
-				return;
-			}
-			iterOk = encoderCaptureListStore.IterNext (ref iter);
-		}
-		encoderButtonsSensitive(encoderSensEnum.DONEYESSIGNAL);
-	}
-	*/
-
-
 
 	string [] treeviewEncoderAnalyzeHeaders = {
 		Catalog.GetString("Repetition") + "\n",
@@ -540,13 +509,14 @@ public partial class ChronoJumpWindow
 		ArrayList curvesData = new ArrayList();
 		string exerciseName = "";
 		double totalMass = 0; 
-		if(check_encoder_analyze_signal_or_curves.Active) {	//current signal
-			exerciseName = UtilGtk.ComboGetActive(combo_encoder_exercise);
+		if(radio_encoder_analyze_individual_current_set.Active) {	//current set
+			exerciseName = UtilGtk.ComboGetActive(combo_encoder_exercise_capture);
 			totalMass = findMass(Constants.MassType.DISPLACED);
-		} else {						//user curves
+		} else {						//not current set
+			//TODO:
 			curvesData = SqliteEncoder.Select(
-					false, -1, currentPerson.UniqueID, currentSession.UniqueID, -1,
-					"curve", EncoderSQL.Eccons.ALL, 
+					false, -1, currentPerson.UniqueID, currentSession.UniqueID, currentEncoderGI,
+					-1, "curve", EncoderSQL.Eccons.ALL, 
 					true, true);
 		}
 
@@ -567,7 +537,7 @@ public partial class ChronoJumpWindow
 				cells = fixDecimals(false, cells);
 				
 				
-				if(! check_encoder_analyze_signal_or_curves.Active) {	//user curves
+				if(! radio_encoder_analyze_individual_current_set.Active) {	//not current set
 					/*
 					 * better don't do this to avoid calling SQL in both treads
 					EncoderSQL eSQL = (EncoderSQL) curvesData[curvesCount];
@@ -610,8 +580,13 @@ public partial class ChronoJumpWindow
 		}
 
 		encoderAnalyzeListStore = new Gtk.ListStore (typeof (EncoderCurve));
-		foreach (EncoderCurve curve in encoderAnalyzeCurves) 
+	
+		repetitiveConditionsWin.ResetBestSetValue();
+		foreach (EncoderCurve curve in encoderAnalyzeCurves) {
 			encoderAnalyzeListStore.AppendValues (curve);
+		
+			repetitiveConditionsWin.UpdateBestSetValue(curve);
+		}
 
 		treeview_encoder_analyze_curves.Model = encoderAnalyzeListStore;
 
@@ -830,9 +805,16 @@ public partial class ChronoJumpWindow
 		return curvesCount;
 	}
 
+	private int createTreeViewEncoderAnalyzeEncoder1RM(string contents) {
+		//buscar o fer algun metode generic que serveixi per mes coses
+		//si pot ser d'una classe diferent a la de ChronojumpWindow
+		
+		return -1;
+	}
 
 
 	/* start rendering capture and analyze cols */
+	
 
 	private string assignColor(double found, bool higherActive, bool lowerActive, double higherValue, double lowerValue) 
 	{
@@ -884,10 +866,6 @@ public partial class ChronoJumpWindow
 		{
 			bool isEven = Util.IsEven(Convert.ToInt32(curve.N));
 			
-			//if we are capturing and has inertia, it comes as 'c','e'
-			if(capturingCsharp == encoderCaptureProcess.CAPTURING && encoderConfigurationCurrent.has_inertia)
-				isEven = !isEven;
-
 			string phase = "e";
 			if(isEven)
 				phase = "c";
@@ -926,7 +904,7 @@ public partial class ChronoJumpWindow
 			return;
 		}
 		
-		if(check_encoder_analyze_signal_or_curves.Active && findEccon(false) == "ecS") 
+		if(radio_encoder_analyze_individual_current_set.Active && findEccon(false) == "ecS") 
 		{
 			string phase = "e";
 			bool isEven = Util.IsEven(Convert.ToInt32(curve.N));
@@ -936,7 +914,7 @@ public partial class ChronoJumpWindow
 			(cell as Gtk.CellRendererText).Text = 
 				decimal.Truncate((Convert.ToInt32(curve.N) +1) /2).ToString() + phase;
 		}
-		else if(check_encoder_analyze_signal_or_curves.Active && findEccon(false) == "ceS") 
+		else if(radio_encoder_analyze_individual_current_set.Active && findEccon(false) == "ceS") 
 		{
 			string phase = "c";
 			bool isEven = Util.IsEven(Convert.ToInt32(curve.N));
@@ -1060,12 +1038,16 @@ public partial class ChronoJumpWindow
 	private void RenderMeanSpeed (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
 	{
 		EncoderCurve curve = (EncoderCurve) model.GetValue (iter, 0);
-		string myColor = assignColor(
-				Convert.ToDouble(curve.MeanSpeed),
-				repetitiveConditionsWin.EncoderMeanSpeedHigher, 
-				repetitiveConditionsWin.EncoderMeanSpeedLower, 
-				repetitiveConditionsWin.EncoderMeanSpeedHigherValue,
-				repetitiveConditionsWin.EncoderMeanSpeedLowerValue);
+
+		string myColor = repetitiveConditionsWin.AssignColorAutomatic(curve, Constants.MeanSpeed);
+		
+		if(myColor == "") 
+			myColor = assignColor(
+					curve.MeanSpeedD,
+					repetitiveConditionsWin.EncoderMeanSpeedHigher, 
+					repetitiveConditionsWin.EncoderMeanSpeedLower, 
+					repetitiveConditionsWin.EncoderMeanSpeedHigherValue,
+					repetitiveConditionsWin.EncoderMeanSpeedLowerValue);
 		if(myColor != "")
 			(cell as Gtk.CellRendererText).Foreground = myColor;
 		else
@@ -1079,12 +1061,16 @@ public partial class ChronoJumpWindow
 	private void RenderMaxSpeed (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
 	{
 		EncoderCurve curve = (EncoderCurve) model.GetValue (iter, 0);
-		string myColor = assignColor(
-				Convert.ToDouble(curve.MaxSpeed),
-				repetitiveConditionsWin.EncoderMaxSpeedHigher, 
-				repetitiveConditionsWin.EncoderMaxSpeedLower, 
-				repetitiveConditionsWin.EncoderMaxSpeedHigherValue,
-				repetitiveConditionsWin.EncoderMaxSpeedLowerValue);
+
+		string myColor = repetitiveConditionsWin.AssignColorAutomatic(curve, Constants.MaxSpeed);
+		
+		if(myColor == "") 
+			myColor = assignColor(
+					curve.MaxSpeedD,
+					repetitiveConditionsWin.EncoderMaxSpeedHigher, 
+					repetitiveConditionsWin.EncoderMaxSpeedLower, 
+					repetitiveConditionsWin.EncoderMaxSpeedHigherValue,
+					repetitiveConditionsWin.EncoderMaxSpeedLowerValue);
 		if(myColor != "")
 			(cell as Gtk.CellRendererText).Foreground = myColor;
 		else
@@ -1106,12 +1092,16 @@ public partial class ChronoJumpWindow
 	private void RenderMeanPower (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
 	{
 		EncoderCurve curve = (EncoderCurve) model.GetValue (iter, 0);
-		string myColor = assignColor(
-				Convert.ToDouble(curve.MeanPower),
-				repetitiveConditionsWin.EncoderPowerHigher, 
-				repetitiveConditionsWin.EncoderPowerLower, 
-				repetitiveConditionsWin.EncoderPowerHigherValue,
-				repetitiveConditionsWin.EncoderPowerLowerValue);
+		
+		string myColor = repetitiveConditionsWin.AssignColorAutomatic(curve, Constants.MeanPower);
+		
+		if(myColor == "") 
+			myColor = assignColor(
+					curve.MeanPowerD,
+					repetitiveConditionsWin.EncoderPowerHigher, 
+					repetitiveConditionsWin.EncoderPowerLower, 
+					repetitiveConditionsWin.EncoderPowerHigherValue,
+					repetitiveConditionsWin.EncoderPowerLowerValue);
 		if(myColor != "")
 			(cell as Gtk.CellRendererText).Foreground = myColor;
 		else
@@ -1124,12 +1114,16 @@ public partial class ChronoJumpWindow
 	private void RenderPeakPower (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
 	{
 		EncoderCurve curve = (EncoderCurve) model.GetValue (iter, 0);
-		string myColor = assignColor(
-				Convert.ToDouble(curve.PeakPower),
-				repetitiveConditionsWin.EncoderPeakPowerHigher, 
-				repetitiveConditionsWin.EncoderPeakPowerLower, 
-				repetitiveConditionsWin.EncoderPeakPowerHigherValue,
-				repetitiveConditionsWin.EncoderPeakPowerLowerValue);
+
+		string myColor = repetitiveConditionsWin.AssignColorAutomatic(curve, Constants.PeakPower);
+		
+		if(myColor == "") 
+			myColor = assignColor(
+					curve.PeakPowerD,
+					repetitiveConditionsWin.EncoderPeakPowerHigher, 
+					repetitiveConditionsWin.EncoderPeakPowerLower, 
+					repetitiveConditionsWin.EncoderPeakPowerHigherValue,
+					repetitiveConditionsWin.EncoderPeakPowerLowerValue);
 		if(myColor != "")
 			(cell as Gtk.CellRendererText).Foreground = myColor;
 		else
@@ -1159,12 +1153,16 @@ public partial class ChronoJumpWindow
 	private void RenderMeanForce (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
 	{
 		EncoderCurve curve = (EncoderCurve) model.GetValue (iter, 0);
-		string myColor = assignColor(
-				Convert.ToDouble(curve.MeanForce),
-				repetitiveConditionsWin.EncoderMeanForceHigher, 
-				repetitiveConditionsWin.EncoderMeanForceLower, 
-				repetitiveConditionsWin.EncoderMeanForceHigherValue,
-				repetitiveConditionsWin.EncoderMeanForceLowerValue);
+
+		string myColor = repetitiveConditionsWin.AssignColorAutomatic(curve, Constants.MeanForce);
+		
+		if(myColor == "") 
+			myColor = assignColor(
+					curve.MeanForceD,
+					repetitiveConditionsWin.EncoderMeanForceHigher, 
+					repetitiveConditionsWin.EncoderMeanForceLower, 
+					repetitiveConditionsWin.EncoderMeanForceHigherValue,
+					repetitiveConditionsWin.EncoderMeanForceLowerValue);
 		if(myColor != "")
 			(cell as Gtk.CellRendererText).Foreground = myColor;
 		else
@@ -1177,12 +1175,16 @@ public partial class ChronoJumpWindow
 	private void RenderMaxForce (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
 	{
 		EncoderCurve curve = (EncoderCurve) model.GetValue (iter, 0);
-		string myColor = assignColor(
-				Convert.ToDouble(curve.MaxForce),
-				repetitiveConditionsWin.EncoderMaxForceHigher, 
-				repetitiveConditionsWin.EncoderMaxForceLower, 
-				repetitiveConditionsWin.EncoderMaxForceHigherValue,
-				repetitiveConditionsWin.EncoderMaxForceLowerValue);
+		
+		string myColor = repetitiveConditionsWin.AssignColorAutomatic(curve, Constants.MaxForce);
+		
+		if(myColor == "") 
+			myColor = assignColor(
+					curve.MaxForceD,
+					repetitiveConditionsWin.EncoderMaxForceHigher, 
+					repetitiveConditionsWin.EncoderMaxForceLower, 
+					repetitiveConditionsWin.EncoderMaxForceHigherValue,
+					repetitiveConditionsWin.EncoderMaxForceLowerValue);
 		if(myColor != "")
 			(cell as Gtk.CellRendererText).Foreground = myColor;
 		else
