@@ -50,6 +50,9 @@ public class GenericWindow
 
 	[Widget] Gtk.SpinButton spin_double;
 	[Widget] Gtk.Box hbox_height_metric;
+	
+	[Widget] Gtk.HButtonBox hbuttonbox_middle;
+	[Widget] Gtk.Button button_middle;
 
 	//Edit row
 	[Widget] Gtk.Box hbox_edit_row;
@@ -110,6 +113,11 @@ public class GenericWindow
 	public int uniqueID;
 	public string nameUntranslated;
 
+	public enum Types { UNDEFINED, ENCODER_SESSION_LOAD, ENCODER_SEL_REPS };
+	//used to decide if a genericWin has to be recreated
+	public Types Type;
+
+
 	public GenericWindow ()
 	{
 		Glade.XML gladeXML;
@@ -139,7 +147,8 @@ public class GenericWindow
 		GenericWindowBox.image_delete.Pixbuf = pixbuf;
 
 		GenericWindowBox.label_header.Text = textHeader;
-		
+
+		GenericWindowBox.Type = Types.UNDEFINED;
 		
 		if(showNow)
 			GenericWindowBox.generic_window.Show ();
@@ -187,6 +196,7 @@ public class GenericWindow
 		hbox_edit_row.Hide();
 		hbox_all_none_selected.Hide();
 		hbox_combo_all_none_selected.Hide();
+		hbuttonbox_middle.Hide();
 		scrolled_window_textview.Hide();
 		scrolled_window_treeview.Hide();
 	}
@@ -252,6 +262,9 @@ public class GenericWindow
 			hbox_combo_all_none_selected.Show();
 			hbox_all_none_selected.Show();
 		}
+		else if(stuff == Constants.GenericWindowShow.BUTTONMIDDLE) {
+			hbuttonbox_middle.Show();
+		}
 		else if(stuff == Constants.GenericWindowShow.TEXTVIEW) {
 			scrolled_window_textview.Show();
 		}
@@ -287,6 +300,8 @@ public class GenericWindow
 			combo.Show();
 			*/
 		}
+		else if(stuff == Constants.GenericWindowShow.BUTTONMIDDLE)
+			hbuttonbox_middle.Show();
 		else if(stuff == Constants.GenericWindowShow.TEXTVIEW)
 			scrolled_window_textview.Show();
 		else //if(stuff == Constants.GenericWindowShow.TREEVIEW)
@@ -337,6 +352,9 @@ public class GenericWindow
 	public void SetSpinDouble2Increments(double min, double max) {
 		spin_double2.SetIncrements(min, max);
 	}
+	public void SetSpinDouble2Range(double min, double max) {
+		spin_double2.SetRange(min, max);
+	}
 	
 	public void SetComboValues(string [] values, string current) {
 		combo = ComboBox.NewText ();
@@ -356,21 +374,29 @@ public class GenericWindow
 	}
 
 	
-	private string [] comboCheckBoxesOptions = {
+	private static string [] comboCheckBoxesOptionsDefault = {
 		Catalog.GetString("All"),
 		Catalog.GetString("None"),
 		Catalog.GetString("Invert"),
 		Catalog.GetString("Selected"),
 	};
+	private string [] comboCheckBoxesOptions = comboCheckBoxesOptionsDefault;
+
+	public void ResetComboCheckBoxesOptions() {
+		comboCheckBoxesOptions = comboCheckBoxesOptionsDefault;
+	}
 	
 	//this search in first column
-	//private string [] addOptionsToComboCheckBoxesOptions(string [] newOptions) {
 	public void AddOptionsToComboCheckBoxesOptions(ArrayList newOptions) {
 		comboCheckBoxesOptions = Util.AddArrayString( comboCheckBoxesOptions, 
 				Util.ArrayListToString(newOptions) );
 	}
 
-	public void CreateComboCheckBoxes() {
+	public void CreateComboCheckBoxes() 
+	{
+		if(hbox_combo_all_none_selected.Children.Length > 0)
+			hbox_combo_all_none_selected.Remove(combo_all_none_selected);
+
 		combo_all_none_selected = ComboBox.NewText ();
 		UtilGtk.ComboUpdate(combo_all_none_selected, comboCheckBoxesOptions, "");
 		
@@ -437,7 +463,9 @@ public class GenericWindow
 		//buttonRecuperateChangeSensitiveness();
 	}
 	
-	
+	public void SetButtonMiddleLabel(string str) {
+		button_middle.Label=str;
+	}
 	
 	public void SetTextview(string str) {
 		TextBuffer tb = new TextBuffer (new TextTagTable());
@@ -460,6 +488,7 @@ public class GenericWindow
 		store = getStore(columnsString.Length, addCheckbox); 
 		treeview.Model = store;
 		prepareHeaders(columnsString, addCheckbox);
+		treeview.HeadersClickable = false;
 
 		nonSensitiveRows = myNonSensitiveRows;
 	
@@ -477,9 +506,11 @@ public class GenericWindow
 		if(contextMenu == Constants.ContextMenu.EDITDELETE) {
 			button_row_edit = new Gtk.Button();
 			button_row_delete = new Gtk.Button();
+			treeview.ButtonReleaseEvent -= on_treeview_button_release_event;
 			treeview.ButtonReleaseEvent += on_treeview_button_release_event;
 		} else if(contextMenu == Constants.ContextMenu.DELETE) {
 			button_row_delete = new Gtk.Button();
+			treeview.ButtonReleaseEvent -= on_treeview_button_release_event;
 			treeview.ButtonReleaseEvent += on_treeview_button_release_event;
 		}
 	}
@@ -581,8 +612,38 @@ public class GenericWindow
 		
 	}
 	
+	public int GetCell(int uniqueID, int column) 
+	{
+		//LogB.Information(" GetCell " + uniqueID.ToString() + " " + column.ToString());
+		Gtk.TreeIter iter;
+		bool okIter = store.GetIterFirst(out iter);
+		if(okIter) {
+			do {
+				//LogB.Information("_0_ " + (string) store.GetValue (iter, 0));
+				//LogB.Information("_column_ " + column.ToString() + " " + (string) store.GetValue (iter, column));
+				if( ((string) store.GetValue (iter, 0)) == uniqueID.ToString()) {
+					return Convert.ToInt32( (string) store.GetValue (iter, column) );
+				}
+			} while ( store.IterNext(ref iter) );
+		}
+
+		return 0;
+	}
+	public string GetCheckboxStatus(int uniqueID) {
+		Gtk.TreeIter iter;
+		bool okIter = store.GetIterFirst(out iter);
+		if(okIter) {
+			do {
+				if( ((string) store.GetValue (iter, 0)) == uniqueID.ToString())
+					return store.GetValue (iter, 1).ToString();
+			} while ( store.IterNext(ref iter) );
+		}
+		//if error, return
+		return "inactive";
+	}
 	//if column == 1 returns checkboxes column. If is 2 returns column 2...
-	public string [] GetCheckboxesStatus(int column, bool onlyActive) 
+	//Attention: Used on checkboxes treeviews
+	public string [] GetColumn(int column, bool onlyActive) 
 	{
 		//to store active or inactive status of curves
 		string [] checkboxes = new string[UtilGtk.CountRows(store)];
@@ -633,6 +694,11 @@ public class GenericWindow
 
 				//check if there are rows checked for having sensitive or not
 				//buttonRecuperateChangeSensitiveness();
+				
+				hbox_error.Hide();
+			} else {
+				label_error.Text = "Cannot select rows without data";
+				hbox_error.Show();
 			}
 		}
 	}
@@ -668,27 +734,32 @@ public class GenericWindow
 		ShowEditRow(false);
 	}
 
+	Menu menuCtx;
 	private void treeviewContextMenu() {
-		Menu myMenu = new Menu ();
+		menuCtx = new Menu ();
 		Gtk.MenuItem myItem;
 
 		if(genericWinContextMenu == Constants.ContextMenu.EDITDELETE) {
 			myItem = new MenuItem ( Catalog.GetString("Edit selected") );
 			myItem.Activated += on_edit_selected_clicked;
-			myMenu.Attach( myItem, 0, 1, 0, 1 );
+			menuCtx.Attach( myItem, 0, 1, 0, 1 );
 
 			myItem = new MenuItem ( Catalog.GetString("Delete selected") );
 			myItem.Activated += on_delete_selected_clicked;
-			myMenu.Attach( myItem, 0, 1, 1, 2 );
+			menuCtx.Attach( myItem, 0, 1, 1, 2 );
 		}
 		else if(genericWinContextMenu == Constants.ContextMenu.DELETE) {
 			myItem = new MenuItem ( Catalog.GetString("Delete selected") );
 			myItem.Activated += on_delete_selected_clicked;
-			myMenu.Attach( myItem, 0, 1, 0, 1 );
+			menuCtx.Attach( myItem, 0, 1, 0, 1 );
+		} else {
+			//don't show nothing if there are no options
+			menuCtx.Popdown();
+			return; 
 		}
 
-		myMenu.Popup();
-		myMenu.ShowAll();
+		menuCtx.Popup();
+		menuCtx.ShowAll();
 	}
 
 	private void on_edit_selected_clicked (object o, EventArgs args) 
@@ -737,8 +808,15 @@ public class GenericWindow
 	public void Delete_row_accepted() {
 		//remove selected row from treeview
 		store = UtilGtk.RemoveRow(treeview, store);
+		menuCtx.Popdown();
 	}
 	
+	public void Row_add(string [] row) {
+		//add row to treeview
+		UtilGtk.TreeviewAddRow(treeview, store, row, true); //insert at beginning
+	}
+	
+	
 	public void ShowTextview() {
 		scrolled_window_textview.Show();
 	}
@@ -802,6 +880,10 @@ public class GenericWindow
 		GenericWindowBox = null;
 	}
 	
+	public Button Button_middle {
+		get { return button_middle; }
+	}
+	
 	public Button Button_delete {
 		set { button_delete = value; }
 		get { return button_delete; }
