@@ -99,7 +99,7 @@ public partial class ChronoJumpWindow
 			button_encoder_select.HeightRequest = 40;
 			//this will make all encoder capture controls taller	
 			//88 then buttons will be the same height than button_encoder_select. The 8 extra is for the vertical space
-			button_encoder_capture.SetSizeRequest(150,88);
+			button_encoder_capture.SetSizeRequest(125,88);
 			//button_encoder_capture.HeightRequest = 88;
 
 			spin_encoder_im_weights_n.Visible = false;
@@ -131,8 +131,10 @@ public partial class ChronoJumpWindow
 		
 
 		//show only power
-		if(config.OnlyEncoder)
-			select_menuitem_mode_toggled(menuitem_modes.POWER);
+		if(config.OnlyEncoderGravitatory)
+			select_menuitem_mode_toggled(Constants.Menuitem_modes.POWERGRAVITATORY);
+		else if(config.OnlyEncoderInertial)
+			select_menuitem_mode_toggled(Constants.Menuitem_modes.POWERINERTIAL);
 		
 		if(config.EncoderCaptureShowOnlyBars) {
 			vpaned_encoder_capture_video_and_set_graph.Visible = false;
@@ -196,7 +198,7 @@ public partial class ChronoJumpWindow
 		/*
 		if(linuxType == linuxTypeEnum.NETWORKS) {
 			//mostrar directament el power
-			select_menuitem_mode_toggled(menuitem_modes.POWER);
+			select_menuitem_mode_toggled(Constants.Menuitem_modes.POWER);
 			
 			//no mostrar menu
 			main_menu.Visible = false;
