@@ -43,7 +43,7 @@ using ICSharpCode.SharpZipLib;
 public class PreferencesWindow {
 	
 	[Widget] Gtk.Window preferences_win;
-
+	[Widget] Gtk.Notebook notebook;
 
 	//main tab
 	[Widget] Gtk.Button button_data_folder_open;
@@ -154,12 +154,19 @@ public class PreferencesWindow {
 		FakeButtonDebugModeStart = new Gtk.Button();
 	}
 	
-	static public PreferencesWindow Show (Preferences preferences)
+	static public PreferencesWindow Show (Preferences preferences, Constants.Menuitem_modes menu_mode)
 	{
 		if (PreferencesWindowBox == null) {
 			PreferencesWindowBox = new PreferencesWindow ();
 		}
 
+		if(menu_mode !=	Constants.Menuitem_modes.JUMPS)
+			PreferencesWindowBox.notebook.GetNthPage(1).Hide(); 
+		if(menu_mode !=	Constants.Menuitem_modes.RUNS)
+			PreferencesWindowBox.notebook.GetNthPage(2).Hide(); 
+		if(menu_mode !=	Constants.Menuitem_modes.POWERGRAVITATORY && menu_mode != Constants.Menuitem_modes.POWERINERTIAL)
+			PreferencesWindowBox.notebook.GetNthPage(3).Hide(); 
+
 		PreferencesWindowBox.preferences = preferences;
 
 		PreferencesWindowBox.createComboLanguage();
@@ -329,6 +336,10 @@ public class PreferencesWindow {
 		UtilGtk.ComboUpdate(combo_camera, devices, "");
 		hbox_combo_camera.PackStart(combo_camera, true, true, 0);
 		hbox_combo_camera.ShowAll();
+
+		if(current >= devices.Length)
+			current = 0;
+		
 		combo_camera.Active = UtilGtk.ComboMakeActive(devices, devices[current]);
 	}
 
