@@ -53,6 +53,10 @@ public partial class ChronoJumpWindow
 		hbox_flicker_lights.Visible = false;
 		hbox_discriminative_lights.Visible = false;
 
+		changeTestImage("","", "reaction_time.png");
+
+		currentReactionTimeType = new ReactionTimeType("reactionTime");
+
 		if(extra_window_radio_reaction_time.Active) {
 			currentReactionTimeType = new ReactionTimeType("reactionTime");
 		} else {
@@ -60,9 +64,11 @@ public partial class ChronoJumpWindow
 				hbox_animation_lights.Visible = true;
 			else if(extra_window_radio_reaction_time_flicker.Active)
 				hbox_flicker_lights.Visible = true;
-			else if(extra_window_radio_reaction_time_discriminative.Active)
+			else if(extra_window_radio_reaction_time_discriminative.Active) {
 				hbox_discriminative_lights.Visible = true;
-
+				currentReactionTimeType = new ReactionTimeType("Discriminative");
+				changeTestImage("","", "reaction_time_discriminative.png");
+			}
 		}
 
 		currentEventType = currentReactionTimeType;
@@ -158,34 +164,92 @@ public partial class ChronoJumpWindow
 
 	// ---- start buttons
 
-	private void on_button_animation_lights_start_clicked (object o, EventArgs args) {
-		int speed = Convert.ToInt32(spinbutton_animation_lights_speed.Value);
-		ChronopicAuto cs = new ChronopicStartReactionTimeAnimation();
-		cs.CharToSend = "l";
-		cs.Write(chronopicWin.SP,speed);
-	}
-	
 	private void on_button_flicker_lights_start_clicked (object o, EventArgs args) {
 		int speed = Convert.ToInt32(spinbutton_flicker_lights_speed.Value);
 		ChronopicAuto cs = new ChronopicStartReactionTimeAnimation();
 		cs.CharToSend = "f";
 		cs.Write(chronopicWin.SP,speed);
+
+		on_button_execute_test_clicked(o, args);
 	}
 
-	private void on_button_discriminative_lights_start_clicked (object o, EventArgs args) {
-		//int speed = Convert.ToInt32(spinbutton_flicker_lights_speed.Value); //TODO
-		ChronopicAuto cs = new ChronopicStartReactionTimeAnimation();
-		if(radiobutton_reaction_time_disc_lr.Active == true)
-			cs.CharToSend = "d";
-		else if(radiobutton_reaction_time_disc_ly.Active == true)
-			cs.CharToSend = "D";
-		else if(radiobutton_reaction_time_disc_lg.Active == true)
-			cs.CharToSend = "i";
-		else if(radiobutton_reaction_time_disc_bz.Active == true)
-			cs.CharToSend = "I";
-		cs.Write(chronopicWin.SP,0); //TODO
+	private string discriminativeCharToSend;
+	private double discriminativeStartTime;
+	private Random rnd;
+
+	//private void on_button_discriminative_lights_start_clicked (object o, EventArgs args) 
+	private void reaction_time_discriminative_lights_prepare () 
+	{
+		//TODO: check if nothing activated, Start should be unsensitive
+
+		if(check_reaction_time_disc_buzzer.Active == true) //all this are with buzzer
+		{
+			if(check_reaction_time_disc_red.Active == true) {
+				if(check_reaction_time_disc_yellow.Active == true) {
+					if(check_reaction_time_disc_green.Active == true)
+						discriminativeCharToSend = "X";		//all lights
+					else
+						discriminativeCharToSend = "U";		//red + yellow
+				} else { //! yellow
+					if(check_reaction_time_disc_green.Active == true)
+						discriminativeCharToSend = "Y";		//red + green
+					else
+						discriminativeCharToSend = "R";		//red
+				}
+			} else {	// ! red
+				if(check_reaction_time_disc_yellow.Active == true) {
+					if(check_reaction_time_disc_green.Active == true)
+						discriminativeCharToSend = "W";		//yellow + green
+					else
+						discriminativeCharToSend = "S";		//yellow
+				} else {	// ! yellow
+					if(check_reaction_time_disc_green.Active == true)
+						discriminativeCharToSend = "T";			//green
+					else
+						discriminativeCharToSend = "Z";			//only buzzer
+				}
+			}
+		} else {					//all this are without buzzer
+			if(check_reaction_time_disc_red.Active == true) {
+				if(check_reaction_time_disc_yellow.Active == true) {
+					if(check_reaction_time_disc_green.Active == true)
+						discriminativeCharToSend = "x";		//all lights
+					else
+						discriminativeCharToSend = "u";		//red + yellow
+				} else { //! yellow
+					if(check_reaction_time_disc_green.Active == true)
+						discriminativeCharToSend = "y";		//red + green
+					else
+						discriminativeCharToSend = "r";		//red
+				}
+			} else {	// ! red
+				if(check_reaction_time_disc_yellow.Active == true) {
+					if(check_reaction_time_disc_green.Active == true)
+						discriminativeCharToSend = "w";		//yellow + green
+					else
+						discriminativeCharToSend = "s";		//yellow
+				} else // ! yellow
+					discriminativeCharToSend = "t";			//green
+			}
+		}
+	
+		rnd = new Random();
+		double rndDouble = rnd.NextDouble(); //double between 0 and 1
+		int range = Convert.ToInt32(spinbutton_discriminative_lights_maximum.Value) - 
+			Convert.ToInt32(spinbutton_discriminative_lights_minimum.Value);
+		discriminativeStartTime = (rndDouble * range) + Convert.ToInt32(spinbutton_discriminative_lights_minimum.Value);
+
+		LogB.Information("discriminativeStartTime");
+		LogB.Information(discriminativeStartTime.ToString());
+						
+		LogB.Information("discriminativeCharToSend");
+		LogB.Information(discriminativeCharToSend);
+		
+		//on_button_execute_test_clicked(o, args);
 	}
 
+
+
 	//---- unused
 	
 	/*
