@@ -70,6 +70,16 @@ public class RepetitiveConditionsWindow
 	[Widget] Gtk.SpinButton spinbutton_time_lower;
 
 	/* encoder */
+	[Widget] Gtk.Frame frame_encoder_automatic_conditions;
+	[Widget] Gtk.HBox hbox_combo_encoder_variable_automatic;
+	[Widget] Gtk.ComboBox combo_encoder_variable_automatic;
+	[Widget] Gtk.CheckButton checkbutton_encoder_automatic_greater;
+	[Widget] Gtk.CheckButton checkbutton_encoder_automatic_lower;
+	[Widget] Gtk.SpinButton spinbutton_encoder_automatic_greater;
+	[Widget] Gtk.SpinButton spinbutton_encoder_automatic_lower;
+
+	[Widget] Gtk.VBox vbox_encoder_manual;
+	[Widget] Gtk.CheckButton checkbutton_encoder_show_manual_feedback;
 	[Widget] Gtk.Notebook notebook_encoder_conditions;
 	[Widget] Gtk.CheckButton checkbutton_encoder_height_higher;
 	[Widget] Gtk.CheckButton checkbutton_encoder_height_lower;
@@ -116,6 +126,7 @@ public class RepetitiveConditionsWindow
 	[Widget] Gtk.Image image_repetitive_tc_lower;
 	[Widget] Gtk.Image image_repetitive_tf_tc_greater;
 	[Widget] Gtk.Image image_repetitive_time_lower;
+	[Widget] Gtk.Image image_repetitive_encoder_automatic_greater;
 	[Widget] Gtk.Image image_encoder_height_higher;
 	[Widget] Gtk.Image image_encoder_mean_speed_higher;
 	[Widget] Gtk.Image image_encoder_max_speed_higher;
@@ -132,6 +143,7 @@ public class RepetitiveConditionsWindow
 	[Widget] Gtk.Image image_repetitive_tc_greater;
 	[Widget] Gtk.Image image_repetitive_tf_tc_lower;
 	[Widget] Gtk.Image image_repetitive_time_greater;
+	[Widget] Gtk.Image image_repetitive_encoder_automatic_lower;
 	[Widget] Gtk.Image image_encoder_height_lower;
 	[Widget] Gtk.Image image_encoder_mean_speed_lower;
 	[Widget] Gtk.Image image_encoder_max_speed_lower;
@@ -145,6 +157,8 @@ public class RepetitiveConditionsWindow
 
 	//static bool volumeOn;
 	bool volumeOn;
+
+	private double bestSetValue;
 	
 	static RepetitiveConditionsWindow RepetitiveConditionsWindowBox;
 		
@@ -161,6 +175,10 @@ public class RepetitiveConditionsWindow
 		
 		FakeButtonClose = new Gtk.Button();
 		
+		createComboEncoderAutomaticVariable();
+
+		bestSetValue = 0;
+
 		putNonStandardIcons();
 	}
 
@@ -195,6 +213,8 @@ public class RepetitiveConditionsWindow
 		hbox_run_best_worst.Hide();
 		hbox_jump_conditions.Hide();
 		hbox_run_conditions.Hide();
+		frame_encoder_automatic_conditions.Hide();
+		vbox_encoder_manual.Hide();
 		notebook_encoder_conditions.Hide();
 
 		if(bellMode == Constants.BellModes.JUMPS) {
@@ -209,9 +229,23 @@ public class RepetitiveConditionsWindow
 			frame_conditions.Show();
 		} else { //encoder
 			notebook_encoder_conditions.CurrentPage = 3; //power
-			notebook_encoder_conditions.Show();
+			frame_encoder_automatic_conditions.Show();
+			vbox_encoder_manual.Show();
+			if(checkbutton_encoder_show_manual_feedback.Active)
+				notebook_encoder_conditions.Show();
 		}
 	}
+		
+	private void createComboEncoderAutomaticVariable() {
+		combo_encoder_variable_automatic = ComboBox.NewText ();
+		string [] values = { Constants.MeanSpeed, Constants.MaxSpeed, Constants.MeanForce, Constants.MaxForce, Constants.MeanPower, Constants.PeakPower };
+		UtilGtk.ComboUpdate(combo_encoder_variable_automatic, values, "");
+		combo_encoder_variable_automatic.Active = UtilGtk.ComboMakeActive(combo_encoder_variable_automatic, "Mean power");
+		
+		hbox_combo_encoder_variable_automatic.PackStart(combo_encoder_variable_automatic, false, false, 0);
+		hbox_combo_encoder_variable_automatic.ShowAll();
+		combo_encoder_variable_automatic.Sensitive = true;
+	}
 
 	private void putNonStandardIcons() {
 		Pixbuf pixbuf;
@@ -223,6 +257,7 @@ public class RepetitiveConditionsWindow
 		image_repetitive_tc_lower.Pixbuf = pixbuf;
 		image_repetitive_tf_tc_greater.Pixbuf = pixbuf;
 		image_repetitive_time_lower.Pixbuf = pixbuf;
+		image_repetitive_encoder_automatic_greater.Pixbuf = pixbuf;
 		image_encoder_height_higher.Pixbuf = pixbuf;
 		image_encoder_mean_speed_higher.Pixbuf = pixbuf;
 		image_encoder_max_speed_higher.Pixbuf = pixbuf;
@@ -240,6 +275,7 @@ public class RepetitiveConditionsWindow
 		image_repetitive_tc_greater.Pixbuf = pixbuf;
 		image_repetitive_tf_tc_lower.Pixbuf = pixbuf;
 		image_repetitive_time_greater.Pixbuf = pixbuf;
+		image_repetitive_encoder_automatic_lower.Pixbuf = pixbuf;
 		image_encoder_height_lower.Pixbuf = pixbuf;
 		image_encoder_mean_speed_lower.Pixbuf = pixbuf;
 		image_encoder_max_speed_lower.Pixbuf = pixbuf;
@@ -324,6 +360,20 @@ public class RepetitiveConditionsWindow
 	}
 
 	/* encoder */
+	void on_spinbutton_encoder_automatic_greater_value_changed (object o, EventArgs args) {
+		checkbutton_encoder_automatic_greater.Active = true;
+	}
+	void on_spinbutton_encoder_automatic_lower_value_changed (object o, EventArgs args) {
+		checkbutton_encoder_automatic_lower.Active = true;
+	}
+			
+	void on_checkbutton_encoder_show_manual_feedback_toggled (object o, EventArgs args) {
+		if(checkbutton_encoder_show_manual_feedback.Active)
+			notebook_encoder_conditions.Show();
+		else
+			notebook_encoder_conditions.Hide();
+	}
+	
 	void on_spinbutton_encoder_height_higher_value_changed (object o, EventArgs args) {
 		checkbutton_encoder_height_higher.Active = true;
 	}
@@ -373,6 +423,55 @@ public class RepetitiveConditionsWindow
 		checkbutton_encoder_peakpower_lower.Active = true;
 	}
 
+			
+	public void ResetBestSetValue() {
+	       bestSetValue = 0;	
+	}
+
+	public void UpdateBestSetValue(EncoderCurve curve) 
+	{
+		string autoVar = encoderAutomaticVariable;
+		if(encoderAutomaticHigher || encoderAutomaticLower) 
+		{
+			if(autoVar == Constants.MeanSpeed)
+				UpdateBestSetValue(curve.MeanSpeedD);
+			else if(autoVar == Constants.MaxSpeed)
+				UpdateBestSetValue(curve.MaxSpeedD);
+			else if(autoVar == Constants.MeanPower)
+				UpdateBestSetValue(curve.MeanPowerD);
+			else if(autoVar == Constants.PeakPower)
+				UpdateBestSetValue(curve.PeakPowerD);
+			else if(autoVar == Constants.MeanForce)
+				UpdateBestSetValue(curve.MeanForceD);
+			else if(autoVar == Constants.MaxForce)
+				UpdateBestSetValue(curve.MaxForceD);
+		}
+	}
+	public void UpdateBestSetValue(double d) {
+		if(d > bestSetValue)
+			bestSetValue = d;
+	}
+		
+	//called from gui/encoderTreeviews.cs
+	public string AssignColorAutomatic(EncoderCurve curve, string variable)
+	{
+		if(encoderAutomaticVariable != variable)
+			return UtilGtk.ColorNothing;
+
+		double currentValue = curve.GetParameter(variable);
+
+		return AssignColorAutomatic(currentValue);
+	}
+	//called from gui/encoder.cs plotCurvesGraphDoPlot
+	public string AssignColorAutomatic(double currentValue)
+	{
+		if(encoderAutomaticHigher && currentValue > bestSetValue * encoderAutomaticHigherValue / 100)
+			return UtilGtk.ColorGood;
+		else if (encoderAutomaticLower && currentValue < bestSetValue * encoderAutomaticLowerValue/ 100)
+			return UtilGtk.ColorBad;
+
+		return UtilGtk.ColorNothing;
+	}
 
 	/* JUMPS */
 	public bool TfTcBest {
@@ -461,6 +560,25 @@ public class RepetitiveConditionsWindow
 	}
 
 	/* ENCODER */
+	//automatic
+
+	private string encoderAutomaticVariable {
+		get { return UtilGtk.ComboGetActive(combo_encoder_variable_automatic); }
+	}
+
+	private bool encoderAutomaticHigher {
+		get { return checkbutton_encoder_automatic_greater.Active; }
+	}
+	private int encoderAutomaticHigherValue {
+		get { return Convert.ToInt32(spinbutton_encoder_automatic_greater.Value); }
+	}
+	private bool encoderAutomaticLower {
+		get { return checkbutton_encoder_automatic_lower.Active; }
+	}
+	private int encoderAutomaticLowerValue {
+		get { return Convert.ToInt32(spinbutton_encoder_automatic_lower.Value); }
+	}
+	
 
 	//height
 	public bool EncoderHeightHigher {
