@@ -254,7 +254,8 @@ public class Server
 				int countE = 0;					
 				int countS = 0;					
 
-				string [] jumps = SqliteJump.SelectJumps(false, currentSession.UniqueID, person.UniqueID, "", "");
+				string [] jumps = SqliteJump.SelectJumps(false, currentSession.UniqueID, person.UniqueID, "", "",
+						Sqlite.Orders_by.DEFAULT, -1);
 				Sqlite.Open();
 				foreach(string myJump in jumps) {
 					string [] js = myJump.Split(new char[] {':'});
@@ -367,7 +368,9 @@ public class Server
 				countE = 0;					
 				countS = 0;					
 
-				string [] runs = SqliteRun.SelectRuns(false, currentSession.UniqueID, person.UniqueID, "");
+				string [] runs = SqliteRun.SelectRuns(false, currentSession.UniqueID, person.UniqueID, "",
+						Sqlite.Orders_by.DEFAULT, -1);
+
 				Sqlite.Open();
 				foreach(string myRun in runs) {
 					string [] js = myRun.Split(new char[] {':'});
@@ -454,7 +457,9 @@ public class Server
 				countE = 0;					
 				countS = 0;					
 
-				string [] rts = SqliteReactionTime.SelectReactionTimes(false, currentSession.UniqueID, person.UniqueID);
+				string [] rts = SqliteReactionTime.SelectReactionTimes(false, currentSession.UniqueID, person.UniqueID,
+						Sqlite.Orders_by.DEFAULT, -1);
+
 				Sqlite.Open();
 				foreach(string myRt in rts) {
 					string [] js = myRt.Split(new char[] {':'});
