@@ -22,6 +22,7 @@ using System;
 using System.Data;
 using System.IO;
 using System.Collections; //ArrayList
+using System.Collections.Generic; //List<T>
 using Mono.Data.Sqlite;
 using Mono.Unix;
 
@@ -204,8 +205,8 @@ class SqliteEncoder : Sqlite
 	//in that conversion, we want first the last ones, and later the previous
 	//	(to delete them if they are old copies)
 	public static ArrayList Select (
-			bool dbconOpened, int uniqueID, int personID, int sessionID, int exerciseID,
-			string signalOrCurve, EncoderSQL.Eccons ecconSelect,
+			bool dbconOpened, int uniqueID, int personID, int sessionID, Constants.EncoderGI encoderGI, 
+			int exerciseID, string signalOrCurve, EncoderSQL.Eccons ecconSelect,
 			bool onlyActive, bool orderIDascendent)
 	{
 		if(! dbconOpened)
@@ -274,6 +275,12 @@ class SqliteEncoder : Sqlite
 				Enum.Parse(typeof(Constants.EncoderConfigurationNames), strFull[0]) );
 			econf.ReadParamsFromSQL(strFull);
 
+			//if encoderGI != ALL discard non wanted repetitions
+			if(encoderGI == Constants.EncoderGI.GRAVITATORY && econf.has_inertia)
+				continue;
+			else if(encoderGI == Constants.EncoderGI.INERTIAL && ! econf.has_inertia)
+				continue;
+
 			LogB.Debug("EncoderConfiguration = " + econf.ToStringOutput(EncoderConfiguration.Outputs.SQL));
 			
 			//if there's no video, will be "".
@@ -315,29 +322,28 @@ class SqliteEncoder : Sqlite
 	}
 	
 
-	public static ArrayList SelectCompareIntersession (bool dbconOpened, int personID)
+	//exerciseID can be -1 to get all exercises
+	public static ArrayList SelectCompareIntersession (bool dbconOpened, Constants.EncoderGI encoderGI, int exerciseID, int personID)
 	{
 		if(! dbconOpened)
 			Sqlite.Open();
-
-		/* OLD, returns a row for active and a row for inactive at each session	
-		dbcmd.CommandText = 
-			"SELECT count(*), encoder.sessionID, session.name, session.date, encoder.status " +
-			" FROM encoder, session, person77 " +
-			" WHERE encoder.personID == " + personID + " AND signalOrCurve == 'curve' AND " + 
-			" encoder.personID == person77.uniqueID AND encoder.sessionID == session.uniqueID " + 
-			" GROUP BY encoder.sessionID, encoder.status ORDER BY encoder.sessionID, encoder.status";
-			*/
+		
+		string exerciseIDStr = "";
+		if(exerciseID != -1)
+			exerciseIDStr = "encoder.exerciseID = " + exerciseID + " AND ";
 
 		//returns a row for each session where there are active or inactive
 		dbcmd.CommandText = 
-			"SELECT encoder.sessionID, session.name, session.date, " +
+			"SELECT encoder.sessionID, session.name, session.date, encoder.extraWeight, " +
 			" SUM(CASE WHEN encoder.status = \"active\" THEN 1 END) as active, " +
-			" SUM(CASE WHEN encoder.status = \"inactive\" THEN 1 END) as inactive " + 
+			" SUM(CASE WHEN encoder.status = \"inactive\" THEN 1 END) as inactive," + 
+			" encoder.encoderConfiguration " +
 			" FROM encoder, session, person77 " +
-			" WHERE encoder.personID == " + personID + " AND signalOrCurve == \"curve\" AND " +
-			" encoder.personID == person77.uniqueID AND encoder.sessionID == session.uniqueID " +
-			" GROUP BY encoder.sessionID ORDER BY encoder.sessionID, encoder.status";
+			" WHERE " +
+			exerciseIDStr + 	
+			" encoder.personID = " + personID + " AND signalOrCurve = \"curve\" AND " +
+			" encoder.personID = person77.uniqueID AND encoder.sessionID = session.uniqueID " +
+			" GROUP BY encoder.sessionID, encoder.extraWeight ORDER BY encoder.sessionID, encoder.extraWeight, encoder.status";
 	
 		LogB.SQL(dbcmd.CommandText.ToString());
 		
@@ -346,28 +352,108 @@ class SqliteEncoder : Sqlite
 
 		ArrayList array = new ArrayList();
 		EncoderPersonCurvesInDB encPS = new EncoderPersonCurvesInDB();
+		/*
+		 * eg.
+		 * sessID|sess name|date|extraWe|a|i (a: active, i: inactive)
+		 * 20|Encoder tests|2012-12-10|7|3|
+		 * 20|Encoder tests|2012-12-10|0||9
+		 * 20|Encoder tests|2012-12-10|10||34
+		 * 20|Encoder tests|2012-12-10|58||1
+		 * 20|Encoder tests|2012-12-10|61||1
+		 * 26|sessio-proves|2013-07-08|10|5|36
+		 * 30|proves encoder|2013-11-08|0|2|
+		 * 30|proves encoder|2013-11-08|100|5|
+		 * 
+		 * convert to:
+		 *
+		 * sessID|sess name|date|a|i|reps*weights	(a: active, i: inactive)
+		 * 20|Encoder tests|2012-12-10|3|45|3*7 9*0 34*10 1*58 1*61 (but sorted)
+		 *
+		 */
+		int sessIDDoing = -1; //of this sessionID
+		int sessIDThisRow = -1; //of this SQL row
+		List<EncoderPersonCurvesInDBDeep> lDeep = new List<EncoderPersonCurvesInDBDeep>();
+		bool firstSession = true;
+		int activeThisRow;
+		int inactiveThisRow;
+		int activeThisSession = 0;
+		int inactiveThisSession = 0;
+
 		while(reader.Read()) {
-			int active = 0;
-			string activeStr = reader[3].ToString();
+			//discard if != encoderGI
+			string [] strFull = reader[6].ToString().Split(new char[] {':'});
+			EncoderConfiguration econf = new EncoderConfiguration(
+				(Constants.EncoderConfigurationNames) 
+				Enum.Parse(typeof(Constants.EncoderConfigurationNames), strFull[0]) );
+
+			//if encoderGI != ALL discard non wanted repetitions
+			if(encoderGI == Constants.EncoderGI.GRAVITATORY && econf.has_inertia)
+				continue;
+			else if(encoderGI == Constants.EncoderGI.INERTIAL && ! econf.has_inertia)
+				continue;
+
+			//1 get sessionID of this row
+			sessIDThisRow = Convert.ToInt32(reader[0].ToString());
+
+			//2 get active an inactive curves of this row
+			activeThisRow = 0;
+			string activeStr = reader[4].ToString();
 			if(Util.IsNumber(activeStr, false))
-				active = Convert.ToInt32(activeStr);
+				activeThisRow = Convert.ToInt32(activeStr);
 			
-			int inactive = 0;
-			string inactiveStr = reader[4].ToString();
+			inactiveThisRow = 0;
+			string inactiveStr = reader[5].ToString();
 			if(Util.IsNumber(inactiveStr, false))
-				inactive = Convert.ToInt32(inactiveStr);
+				inactiveThisRow = Convert.ToInt32(inactiveStr);
+			
+			//3 if session of this row is different than previous row
+			if(sessIDThisRow != sessIDDoing) 
+			{
+				sessIDDoing = sessIDThisRow;
 
+				if(! firstSession) {
+					//if is not first session (means we have processed a session before)
+					//update encPS with the lDeep and then add to array
+					encPS.lDeep = lDeep;
+					encPS.countActive = activeThisSession;
+					encPS.countAll = activeThisSession + inactiveThisSession;
+					array.Add(encPS);
+				}
 
-			encPS = new EncoderPersonCurvesInDB (
-					personID,
-					Convert.ToInt32(reader[0].ToString()),	//sessionID
-					reader[1].ToString(),			//sessionName
-					reader[2].ToString(),			//sessionDate
-					active,					//active
-					active + inactive			//all: active + inactive 
-					);
+				firstSession = false;
+
+				//create new EncoderPersonCurvesInDB
+				encPS = new EncoderPersonCurvesInDB (
+						personID,
+						Convert.ToInt32(reader[0].ToString()),	//sessionID
+						reader[1].ToString(),			//sessionName
+						reader[2].ToString());			//sessionDate
+					
+				activeThisSession = 0;
+				inactiveThisSession = 0;
+				//empty lDeep
+				lDeep = new List<EncoderPersonCurvesInDBDeep>();
+			}
+			//4 add deep info: (weight, all reps)
+			EncoderPersonCurvesInDBDeep deep = new EncoderPersonCurvesInDBDeep(
+					Convert.ToDouble(Util.ChangeDecimalSeparator(reader[3].ToString())), activeThisRow + inactiveThisRow);
+			//add to lDeep
+			lDeep.Add(deep);
+			
+			activeThisSession += activeThisRow;
+			inactiveThisSession += inactiveThisRow;
+		}
+		
+		//store last row in array (once we are out the while)
+		if(! firstSession) {
+			//if is not first session (means we have processed a session before)
+			//update encPS with the lDeep and then add to array
+			encPS.lDeep = lDeep;
+			encPS.countActive = activeThisSession;
+			encPS.countAll = activeThisSession + inactiveThisSession;
 			array.Add(encPS);
 		}
+
 		reader.Close();
 		if(! dbconOpened)
 			Sqlite.Close();
@@ -375,13 +461,13 @@ class SqliteEncoder : Sqlite
 		return array;
 	}
 	
-	public static ArrayList SelectSessionOverview (bool dbconOpened, int sessionID)
+	public static ArrayList SelectSessionOverview (bool dbconOpened, Constants.EncoderGI encoderGI, int sessionID)
 	{
 		if(! dbconOpened)
 			Sqlite.Open();
 	
 		dbcmd.CommandText = 
-			"SELECT person77.name, encoderExercise.name, (personSession77.weight * encoderExercise.percentBodyWeight/100) + encoder.extraWeight, COUNT(*)" + 
+			"SELECT person77.name, encoder.encoderConfiguration, encoderExercise.name, (personSession77.weight * encoderExercise.percentBodyWeight/100) + encoder.extraWeight, COUNT(*)" + 
 			" FROM person77, personSession77, encoderExercise, encoder" + 
 			" WHERE person77.uniqueID == encoder.personID AND personSession77.personID == encoder.personID AND personSession77.sessionID == encoder.sessionID AND encoderExercise.uniqueID==encoder.exerciseID AND signalOrCurve == \"signal\" AND encoder.sessionID == " + sessionID + 
 			" GROUP BY encoder.personID, exerciseID, extraWeight" +
@@ -395,14 +481,36 @@ class SqliteEncoder : Sqlite
 		ArrayList array = new ArrayList();
 		int count = 0;
 		while(reader.Read()) { 
-			string [] s = { 
-				(count++).ToString(),	//not displayed but needed on genericWin.SetTreeView
-				reader[0].ToString(), 	//person name
-				reader[1].ToString(), 	//encoder exercise name
-				reader[2].ToString(),	//displaced mass (includes percentBodyeight)
-				reader[3].ToString()	//sets count
+			//discard if != encoderGI
+			string [] strFull = reader[1].ToString().Split(new char[] {':'});
+			EncoderConfiguration econf = new EncoderConfiguration(
+				(Constants.EncoderConfigurationNames) 
+				Enum.Parse(typeof(Constants.EncoderConfigurationNames), strFull[0]) );
+
+			//if encoderGI != ALL discard non wanted repetitions
+			if(encoderGI == Constants.EncoderGI.GRAVITATORY && econf.has_inertia)
+				continue;
+			else if(encoderGI == Constants.EncoderGI.INERTIAL && ! econf.has_inertia)
+				continue;
+
+			if(encoderGI == Constants.EncoderGI.GRAVITATORY) {
+				string [] s = { 
+					(count++).ToString(),	//not displayed but needed on genericWin.SetTreeView
+					reader[0].ToString(), 	//person name
+					reader[2].ToString(), 	//encoder exercise name
+					reader[3].ToString(),	//displaced mass (includes percentBodyeight)
+					reader[4].ToString()	//sets count
 				};
-			array.Add (s);
+				array.Add (s);
+			} else {
+				string [] s = { 
+					(count++).ToString(),	//not displayed but needed on genericWin.SetTreeView
+					reader[0].ToString(), 	//person name
+					reader[2].ToString(), 	//encoder exercise name
+					reader[4].ToString()	//sets count
+				};
+				array.Add (s);
+			}
 		}
 
 		reader.Close();
@@ -785,7 +893,7 @@ class SqliteEncoder : Sqlite
 		dbcmd.ExecuteNonQuery();
 	}
 	
-	public static void Insert1RM(bool dbconOpened, int personID, int sessionID, int exerciseID, double load1RM)	
+	public static int Insert1RM(bool dbconOpened, int personID, int sessionID, int exerciseID, double load1RM)	
 	{
 		if(! dbconOpened)
 			Sqlite.Open();
@@ -796,11 +904,19 @@ class SqliteEncoder : Sqlite
 				exerciseID + ", " + Util.ConvertToPoint(load1RM) + ", \"\",\"\",\"\")";
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
+		
+		//int myLast = dbcon.LastInsertRowId;
+		//http://stackoverflow.com/questions/4341178/getting-the-last-insert-id-with-sqlite-net-in-c
+		string myString = @"select last_insert_rowid()";
+		dbcmd.CommandText = myString;
+		int myLast = Convert.ToInt32(dbcmd.ExecuteScalar()); // Need to type-cast since `ExecuteScalar` returns an object.
 
 		if(! dbconOpened)
 			Sqlite.Close();
+
+		return myLast;
 	}
-	
+
 	public static ArrayList Select1RM (bool dbconOpened, int personID, int sessionID, int exerciseID, bool returnPersonNameAndExerciseName)
 	{
 		if(! dbconOpened)
@@ -835,12 +951,13 @@ class SqliteEncoder : Sqlite
 		}
 
 		if(returnPersonNameAndExerciseName)
-			dbcmd.CommandText = "SELECT " + Constants.Encoder1RMTable + ".*, person77.name, encoderExercise.name" + 
-				" FROM " + Constants.Encoder1RMTable + ", person77, encoderExercise " +
-				whereStr +
+			dbcmd.CommandText = "SELECT " + Constants.Encoder1RMTable + ".*, person77.name, encoderExercise.name, session.date" + 
+				" FROM " + Constants.Encoder1RMTable + ", person77, encoderExercise, session " +
+				whereStr + " AND " + Constants.Encoder1RMTable + ".sessionID = session.uniqueID " +
 				" ORDER BY uniqueID DESC"; //this allows to select the last uniqueID because will be the first in the returned array 
 		else
-			dbcmd.CommandText = "SELECT * FROM " + Constants.Encoder1RMTable + whereStr +
+			dbcmd.CommandText = "SELECT " + Constants.Encoder1RMTable + ".*, session.date FROM " + 
+				Constants.Encoder1RMTable + ", session" + whereStr +
 				" ORDER BY uniqueID DESC"; //this allows to select the last uniqueID because will be the first in the returned array 
 
 		LogB.SQL(dbcmd.CommandText.ToString());
@@ -857,6 +974,7 @@ class SqliteEncoder : Sqlite
 						Convert.ToInt32(reader[0].ToString()),	//uniqueID
 						Convert.ToInt32(reader[1].ToString()),	//personID	
 						Convert.ToInt32(reader[2].ToString()),	//sessionID
+						UtilDate.FromSql(reader[10].ToString()),//date
 						Convert.ToInt32(reader[3].ToString()),	//exerciseID
 						Convert.ToDouble(Util.ChangeDecimalSeparator(reader[4].ToString())),  //load1RM
 						reader[8].ToString(),	//personName
@@ -867,6 +985,7 @@ class SqliteEncoder : Sqlite
 						Convert.ToInt32(reader[0].ToString()),	//uniqueID
 						Convert.ToInt32(reader[1].ToString()),	//personID	
 						Convert.ToInt32(reader[2].ToString()),	//sessionID
+						UtilDate.FromSql(reader[5].ToString()),		//date
 						Convert.ToInt32(reader[3].ToString()),	//exerciseID
 						Convert.ToDouble(Util.ChangeDecimalSeparator(reader[4].ToString()))  //load1RM
 						);
