@@ -58,6 +58,7 @@ class Sqlite
 	static bool creatingBlankDatabase = false;
 
 	
+	public enum Orders_by { DEFAULT, ID_DESC }
 
 	//for db creation
 	static int creationRate;
@@ -1531,8 +1532,10 @@ class Sqlite
 		
 				SqliteEncoder.createTableEncoderSignalCurve();
 
-				ArrayList signals = SqliteEncoder.Select(true, -1, -1, -1, -1, "signal", EncoderSQL.Eccons.ALL, false, false);
-				ArrayList curves = SqliteEncoder.Select(true, -1, -1, -1, -1, "curve", EncoderSQL.Eccons.ALL, false, false);
+				ArrayList signals = SqliteEncoder.Select(true, -1, -1, -1, Constants.EncoderGI.ALL,
+						-1, "signal", EncoderSQL.Eccons.ALL, false, false);
+				ArrayList curves = SqliteEncoder.Select(true, -1, -1, -1, Constants.EncoderGI.ALL,
+						-1, "curve", EncoderSQL.Eccons.ALL, false, false);
 				int signalID;
 				conversionRateTotal = signals.Count;
 				conversionRate = 1;
