@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -72,10 +72,10 @@ class SqlitePreferences : Sqlite
 
 				Insert ("runDoubleContactsMode", 
 						Constants.DoubleContact.LAST.ToString(), dbcmdTr); 
-				Insert ("runDoubleContactsMS", "1000", dbcmdTr);
+				Insert ("runDoubleContactsMS", "300", dbcmdTr);
 				Insert ("runIDoubleContactsMode", 
 						Constants.DoubleContact.AVERAGE.ToString(), dbcmdTr); 
-				Insert ("runIDoubleContactsMS", "1000", dbcmdTr);
+				Insert ("runIDoubleContactsMS", "300", dbcmdTr);
 
 				Random rnd = new Random();
 				string machineID = rnd.Next().ToString();
@@ -92,7 +92,7 @@ class SqlitePreferences : Sqlite
 				Insert ("CSVExportDecimalSeparator", Util.GetDecimalSeparatorFromLocale(), dbcmdTr);
 				Insert ("RGraphsTranslate", "True", dbcmdTr);
 				Insert ("useHeightsOnJumpIndexes", "True", dbcmdTr);
-				Insert ("encoderAutoSaveCurve", Constants.EncoderAutoSaveCurve.BESTMEANPOWER.ToString(), dbcmdTr); 
+				Insert ("encoderAutoSaveCurve", Constants.EncoderAutoSaveCurve.BEST.ToString(), dbcmdTr); 
 				Insert ("email", "", dbcmdTr);
 				
 				//last encoderConfiguration, to be used on next session
@@ -113,8 +113,8 @@ class SqlitePreferences : Sqlite
 	{
 		//Sqlite.Open();
 		mycmd.CommandText = "INSERT INTO " + Constants.PreferencesTable + 
-			" (name, value) VALUES ('" + 
-			myName + "', '" + myValue + "')" ;
+			" (name, value) VALUES (\"" + 
+			myName + "\", \"" + myValue + "\")" ;
 		LogB.SQL(mycmd.CommandText.ToString());
 		mycmd.ExecuteNonQuery();
 		//Sqlite.Close();
@@ -126,8 +126,8 @@ class SqlitePreferences : Sqlite
 			Sqlite.Open();
 
 		dbcmd.CommandText = "UPDATE " + Constants.PreferencesTable +
-			" SET value = '" + myValue + 
-			"' WHERE name == '" + myName + "'" ;
+			" SET value = \"" + myValue + 
+			"\" WHERE name == \"" + myName + "\"" ;
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 		
@@ -147,7 +147,7 @@ class SqlitePreferences : Sqlite
 			Sqlite.Open();
 
 		dbcmd.CommandText = "SELECT value FROM " + Constants.PreferencesTable + 
-			" WHERE name == '" + myName + "'" ;
+			" WHERE name == \"" + myName + "\"" ;
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 		
