@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2016   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -65,13 +65,13 @@ class SqliteRunInterval : SqliteRun
 		dbcmd.CommandText = "INSERT INTO "+ tableName + 
 				" (uniqueID, personID, sessionID, type, distanceTotal, timeTotal, distanceInterval, intervalTimesString, tracks, description, limited, simulated, initialSpeed)" +
 				"VALUES (" + uniqueID + ", " +
-				personID + ", " + sessionID + ", '" + type + "', " +
+				personID + ", " + sessionID + ", \"" + type + "\", " +
 				Util.ConvertToPoint(distanceTotal) + ", " + 
 				Util.ConvertToPoint(timeTotal) + ", " + 
-				Util.ConvertToPoint(distanceInterval) + ", '" + 
-				Util.ConvertToPoint(intervalTimesString) + "', " +
-				Util.ConvertToPoint(tracks) + ", '" + 
-				description + "', '" + limited + "', " + simulated + ", " +
+				Util.ConvertToPoint(distanceInterval) + ", \"" + 
+				Util.ConvertToPoint(intervalTimesString) + "\", " +
+				Util.ConvertToPoint(tracks) + ", \"" + 
+				description + "\", \"" + limited + "\", " + simulated + ", " +
 				Util.BoolToInt(initialSpeed) + ")" ;
 				
 		LogB.SQL(dbcmd.CommandText.ToString());
@@ -106,7 +106,7 @@ class SqliteRunInterval : SqliteRun
 
 		string filterTypeString = "";
 		if(filterType != "")
-			filterTypeString = " AND runInterval.type == '" + filterType + "' " ;
+			filterTypeString = " AND runInterval.type == \"" + filterType + "\" " ;
 
 		dbcmd.CommandText = "SELECT " + tp + ".name, runInterval.* " +
 			" FROM " + tp + ", runInterval " +
@@ -189,8 +189,8 @@ class SqliteRunInterval : SqliteRun
 		Sqlite.Open();
 		dbcmd.CommandText = "UPDATE " + Constants.RunIntervalTable +
 			" SET personID = " + personID + 
-			", description = '" + description +
-			"' WHERE uniqueID == " + runID ;
+			", description = \"" + description +
+			"\" WHERE uniqueID == " + runID ;
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 		Sqlite.Close();
