@@ -730,36 +730,46 @@ public class Util
 		string lastPartOfPath = fileName.Substring(posOfBar+1, fileName.Length - posOfBar -1);
 		return lastPartOfPath;
 	}
+	
+	public static void IsNumberTests() {
+		LogB.Information("tryParse -23 as int: " + Util.IsNumber("-23",false).ToString()); 	//catalan (True)
+		LogB.Information("tryParse -23.75 as int: " + Util.IsNumber("-23.75",false).ToString()); 	//catalan (False)
+		LogB.Information("tryParse -23,75 as int: " + Util.IsNumber("-23,75",false).ToString()); 	//catalan (False)
+		
+		LogB.Information("tryParse -23.75 as double: " + Util.IsNumber("-23.75",true).ToString()); //catalan (False)
+		LogB.Information("tryParse -23,75 as double: " + Util.IsNumber("-23,75",true).ToString()); //catalan (True)
+		
+		LogB.Information("tryParse '' as int: " + Util.IsNumber("",false).ToString()); 		//catalan (True)
+		LogB.Information("tryParse '' as double: " + Util.IsNumber("",true).ToString()); 	//catalan (True)
+		
+		LogB.Information("tryParse 'joan' as int: " + Util.IsNumber("joan",false).ToString()); 	//catalan (True)
+		LogB.Information("tryParse 'joan' as double: " + Util.IsNumber("joan",true).ToString()); //catalan (True)
+	}
 
 	//gets a string and returns if all the chars are numbers or the decimal point in current localization
-	//there should be also only one decimal point
-	//method made because i didn't find it in mono
-	//ATTENTTION ONLY WORKS FOR POSITIVES
-	//before changing this method, better create another method for all numbers, 
-	//and call that method on possible negative numbers
-	//
-	//On EncoderCurve class there's the method IsNumber that's better, but does not check if the decimal point is a different character
-	public static bool IsNumber(string myString, bool canBeDecimal) {
-		System.Globalization.NumberFormatInfo localeInfo = new System.Globalization.NumberFormatInfo();
-		localeInfo = System.Globalization.NumberFormatInfo.CurrentInfo;
+	public static bool IsNumber(string str, bool canBeDecimal) 
+	{
+		//false if it's blank
+		if(str.Length == 0)
+			return false;
 		
-		int countDecimals = 0;
-		foreach(char myChar in myString) {
-			if( ! System.Char.IsNumber(myChar) && myChar.ToString() != localeInfo.NumberDecimalSeparator ) {
-				return false;
-			}
-			if( myChar.ToString() == localeInfo.NumberDecimalSeparator ) {
-				countDecimals ++;
-			}
+		if(canBeDecimal) {
+			double numD;
+			//param 2 && 3 are needed on latin languages to achieve a negative result on "23.75"
+			//without those params, "23.75" and "23,75" will be true on latin. Undesired
+			if (double.TryParse(
+						str,
+						System.Globalization.NumberStyles.Float,	
+						System.Globalization.NumberFormatInfo.CurrentInfo,	
+						out numD))
+				return true;
 		}
-		if(countDecimals > 0 && !canBeDecimal) { return false; }
-		if(countDecimals > 1) { return false; }
 
-		//false if it's blank, or it's only a decimal "."
-		if(myString.Length == 0 || (myString.Length == 1 && countDecimals == 1)) { 
-			return false; }
-				
-		return true;
+		int numI;	
+		if (int.TryParse(str, out numI))
+			return true;
+
+		return false;
 	}
 
 	public static bool IsEven(string myString) {
@@ -1366,6 +1376,22 @@ public class Util
 
 		return myArrayList;
 	}
+	
+	public static ArrayList AddToArrayListIfNotExist(ArrayList myArrayList, double d) {
+	 	bool found = FoundInArrayList(myArrayList, d);
+		if(!found)
+			myArrayList.Add(d);
+
+		return myArrayList;
+	}
+	
+	public static List<double> AddToListDoubleIfNotExist(List<double> l, double d) {
+	 	bool found = FoundInListDouble(l, d);
+		if(!found)
+			l.Add(d);
+	
+		return l;
+	}
 
 	public static bool FoundInArrayList(ArrayList a, string str) {
 		foreach (string str2 in a)
@@ -1377,7 +1403,15 @@ public class Util
 
 	public static bool FoundInArrayList(ArrayList a, int i) {
 		foreach (int j in a)
-			if(i == j)
+			if(j == i)
+				return true;
+
+		return false;
+	}
+
+	public static bool FoundInArrayList(ArrayList a, double d) {
+		foreach (double d2 in a)
+			if(d2 == d)
 				return true;
 
 		return false;
@@ -1391,6 +1425,14 @@ public class Util
 		return false;
 	}
 
+	public static bool FoundInListDouble(List<double>l, double d) {
+		foreach (double d2 in l)
+			if(d2 == d)
+				return true;
+
+		return false;
+	}
+
 	public static ArrayList RemoveLastArrayElement(ArrayList a) {
 		if(a.Count > 0)
 			a.RemoveAt(a.Count - 1);
@@ -1555,11 +1597,16 @@ public class Util
 	//thought for being between 0, 1
 	//ideal for progressBars
 	public static double DivideSafeFraction (double val1, double val2) {
+		if(val1 == 0 || val2 == 0)
+			return 0;
+
 		double result = val1 / val2;
+		
 		if(result > 1)
 			result = 1;
 		else if(result < 0)
 			result = 0;
+
 		return result;
 	}
 	
@@ -1648,7 +1695,8 @@ public class Util
 			return tracks * distanceInterval;
 	}
 
-	public static double GetRunIVariableDistancesSpeeds(string distancesString, string timesString, bool max) {
+	public static double GetRunIVariableDistancesSpeeds(string distancesString, string timesString, bool max) 
+	{
 		double  searchedValue = -1; //to find max values (higher than this)
 		if(! max)
 			searchedValue = 1000; //to find min values (lower than this)
@@ -1660,13 +1708,26 @@ public class Util
 		
 			int distPos = i % times.Length;
 
+			/*
+			 * A test limited by time or undefined can have 
+			 * timesString: 3,595518=6,971076=7,427422=8,109596 (4 values) 
+			 * and distancesString 12-3-5 (3 values)
+			 */
+			if(distPos >= distances.Length)
+				continue;
+
 			//RSA is not counted as speed
 			if(distances[distPos].StartsWith("R"))
 				continue;
 
 			double distance = Convert.ToDouble(distances[distPos]);
 
-			double speed = distance / time;
+			double speed;
+			if(distance == 0 || time == 0)
+				speed = 0;
+			else
+				speed = distance / time;
+
 			if(max) {
 				if(speed > searchedValue) 
 					searchedValue = speed;
@@ -1706,7 +1767,13 @@ public class Util
 			} else 
 				distance = distanceInterval;
 
-			speeds += sep + (distance / time * 1.0).ToString();
+			double speedNow;
+			if(distance == 0 || time == 0)
+				speedNow = 0;
+			else
+				speedNow = distance / time;
+			
+			speeds += sep + (speedNow * 1.0).ToString();
 			sep = separator;
 		}
 		//fill the row with 0's equalling largest row
