@@ -22,6 +22,7 @@ using System;
 //using System.Data;
 using System.Text; //StringBuilder
 using System.Collections; //ArrayList
+using System.Collections.Generic; //List<T>
 using System.Diagnostics; 	//for detect OS and for Process
 using System.IO; 		//for detect OS
 using Mono.Unix;
@@ -295,7 +296,7 @@ public class UtilEncoder
 	}
 	*/
 	
-	public static EncoderGraphROptions PrepareEncoderGraphOptions(string title, EncoderStruct es, bool neuromuscularProfileDo, bool translate, bool debug) 
+	public static EncoderGraphROptions PrepareEncoderGraphOptions(string title, EncoderStruct es, bool neuromuscularProfileDo, bool translate, bool debug, bool crossValidate) 
 	{
 		string operatingSystem = "Linux";
 			
@@ -351,7 +352,7 @@ public class UtilEncoder
 				title, operatingSystem,
 				Util.StringArrayToString(Constants.EncoderEnglishWords,";"),
 				Util.StringArrayToString(encoderTranslatedWordsOK,";"),
-				debug
+				debug, crossValidate
 				);
 	}
 
@@ -803,6 +804,29 @@ public class UtilEncoder
 
 		return econf.inertiaMachine + im_weights;
 	}
+
+	public static int GetActiveCurvesNum(ArrayList curvesArray) {
+		int countActiveCurves = 0;
+		foreach(EncoderSQL es in curvesArray) 
+			if(es.status == "active")
+				countActiveCurves ++;
+		
+		return countActiveCurves;
+	}
+	
+	public static List<int> GetActiveCheckboxesList(string [] checkboxes) {
+		List<int> activeCurvesList = new List<int>();
+		int i=0;
+		foreach(string cb in checkboxes) {
+			if(cb == "active")
+				activeCurvesList.Add(i+1);
+			i++;
+		}
+		return activeCurvesList;
+	}
+	
+
+
 		
 
 }
